import React from 'react';
import styled from 'styled-components';
import VideoBackground from './components/VideoBackground';
import CountdownTimer from './components/CountdownTimer';
import Statistics from './components/Statistics';
import RegisterButton from './components/RegisterButton';
import Footer from './components/Footer';
import HighlightGallery from './components/HighlightGallery';
import FeatureSection from './components/FeatureSection';
import BehindTheScenes from './components/BehindTheScenes';

const AppContainer = styled.div`
  min-height: 100vh;
  position: relative;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: space-between;
  overflow: hidden;
`;

const ContentOverlay = styled.div`
  position: relative;
  z-index: 2;
  width: 100%;
  max-width: 1000px;
  display: flex;
  flex-direction: column;
  align-items: center;
  text-align: center;
  background: linear-gradient(135deg, rgba(26, 156, 176, 0.7), rgba(13, 78, 109, 0.8));
  padding: 50px 30px;
  border-radius: 10px;
  backdrop-filter: blur(8px);
  border: 2px solid rgba(0, 226, 199, 0.6);
  box-shadow: 0 0 40px rgba(0, 243, 255, 0.4), 0 0 20px rgba(0, 226, 199, 0.5);
  margin-top: 50px;
`;

const Title = styled.h1`
  font-size: 5.5rem;
  font-weight: 800;
  margin-bottom: 1rem;
  text-transform: uppercase;
  color: white;
  text-shadow: 0 0 10px var(--neon-red), 0 0 20px var(--neon-red);
  animation: redNeonPulse 1.5s infinite alternate;
  letter-spacing: 2px;

  @media (max-width: 768px) {
    font-size: 3rem;
  }
`;

const Tagline = styled.h2`
  font-size: 2.5rem;
  font-weight: 700;
  margin-bottom: 3rem;
  text-transform: uppercase;
  background: linear-gradient(to right, white, var(--bright-yellow));
  -webkit-background-clip: text;
  -webkit-text-fill-color: transparent;
  text-shadow: 0 0 5px rgba(255, 255, 255, 0.7);

  @media (max-width: 768px) {
    font-size: 1.5rem;
  }
`;

const Triangle = styled.div`
  width: 0;
  height: 0;
  border-left: 25px solid transparent;
  border-right: 25px solid transparent;
  border-bottom: 43px solid var(--bright-yellow);
  position: absolute;
  top: -60px;
  opacity: 0.9;
`;

const Circle = styled.div`
  width: 40px;
  height: 40px;
  border-radius: 50%;
  background-color: var(--neon-pink);
  position: absolute;
  top: -60px;
  right: 20%;
  opacity: 0.9;
`;

const Square = styled.div`
  width: 40px;
  height: 40px;
  background-color: var(--neon-blue);
  position: absolute;
  top: -60px;
  left: 20%;
  opacity: 0.9;
`;

const HiddenAdminLink = styled.div`
  position: fixed;
  bottom: 5px;
  right: 5px;
  font-size: 0.7rem;
  opacity: 0.2;
  z-index: 1;
  
  a {
    color: #444;
    text-decoration: none;
    
    &:hover {
      color: #666;
    }
  }
`;

function App() {
  return (
    <AppContainer>
      <VideoBackground />
      <ContentOverlay>
        <Triangle />
        <Circle />
        <Square />
        <Title>Squid Game 2</Title>
        <Tagline>Change Your Life In 6 Games</Tagline>
        <CountdownTimer />
        <Statistics />
        <RegisterButton />
      </ContentOverlay>
      
      <HighlightGallery />
      <FeatureSection />
      <BehindTheScenes />
      
      <HiddenAdminLink>
        <a href="/management-console">.</a>
      </HiddenAdminLink>
      <Footer />
    </AppContainer>
  );
}

export default App; 