import React, { useState } from 'react';
import styled from 'styled-components';

const AdminContainer = styled.div`
  padding: 30px;
  background-color: #111;
  min-height: 100vh;
  color: white;
`;

const AdminHeader = styled.div`
  display: flex;
  justify-content: space-between;
  align-items: center;
  margin-bottom: 30px;
  border-bottom: 1px solid rgba(255, 0, 60, 0.3);
  padding-bottom: 15px;
`;

const AdminTitle = styled.h1`
  font-size: 2rem;
  color: white;
  text-shadow: 0 0 10px var(--neon-red);
  margin: 0;
`;

const LogoutButton = styled.button`
  background: transparent;
  border: 1px solid var(--neon-red);
  color: white;
  padding: 8px 16px;
  border-radius: 4px;
  cursor: pointer;
  
  &:hover {
    background-color: var(--neon-red);
    box-shadow: 0 0 10px var(--neon-red);
  }
`;

const DashboardGrid = styled.div`
  display: grid;
  grid-template-columns: 250px 1fr;
  gap: 30px;
  height: calc(100vh - 100px);
`;

const Sidebar = styled.div`
  background-color: #222;
  border-radius: 8px;
  padding: 20px;
  border: 1px solid rgba(255, 0, 60, 0.3);
`;

const MainContent = styled.div`
  background-color: #222;
  border-radius: 8px;
  padding: 20px;
  border: 1px solid rgba(255, 0, 60, 0.3);
  overflow-y: auto;
`;

const NavItem = styled.div`
  padding: 12px 15px;
  cursor: pointer;
  border-radius: 4px;
  margin-bottom: 8px;
  background-color: ${props => props.active ? 'rgba(255, 0, 60, 0.3)' : 'transparent'};
  
  &:hover {
    background-color: ${props => props.active ? 'rgba(255, 0, 60, 0.3)' : 'rgba(255, 0, 60, 0.1)'};
  }
`;

const SectionTitle = styled.h2`
  font-size: 1.5rem;
  margin-bottom: 20px;
  color: var(--neon-red);
  border-bottom: 1px solid rgba(255, 255, 255, 0.1);
  padding-bottom: 10px;
`;

const SearchContainer = styled.div`
  display: flex;
  margin-bottom: 20px;
  gap: 10px;
`;

const SearchInput = styled.input`
  flex: 1;
  padding: 10px;
  background-color: #333;
  border: 1px solid #444;
  border-radius: 4px;
  color: white;
  
  &:focus {
    outline: none;
    border-color: var(--neon-red);
  }
`;

const FilterButton = styled.button`
  background-color: #333;
  border: 1px solid #444;
  color: white;
  padding: 10px 15px;
  border-radius: 4px;
  cursor: pointer;
  
  &:hover {
    background-color: #444;
  }
`;

const ParticipantTable = styled.table`
  width: 100%;
  border-collapse: collapse;
  
  th, td {
    padding: 12px 15px;
    text-align: left;
    border-bottom: 1px solid rgba(255, 255, 255, 0.1);
  }
  
  th {
    background-color: rgba(255, 0, 60, 0.1);
    color: var(--neon-red);
  }
  
  tr:hover {
    background-color: rgba(255, 255, 255, 0.05);
  }
`;

const ActionButton = styled.button`
  background-color: ${props => props.secondary ? 'transparent' : 'var(--neon-red)'};
  color: white;
  border: ${props => props.secondary ? '1px solid var(--neon-red)' : 'none'};
  padding: 5px 10px;
  border-radius: 4px;
  margin-right: 5px;
  cursor: pointer;
  
  &:hover {
    background-color: ${props => props.secondary ? 'rgba(255, 0, 60, 0.2)' : 'rgba(255, 0, 60, 0.8)'};
  }
`;

const StatusBadge = styled.span`
  display: inline-block;
  padding: 4px 8px;
  border-radius: 12px;
  font-size: 0.85rem;
  background-color: ${props => {
    switch(props.status) {
      case 'approved': return 'rgba(0, 255, 0, 0.2)';
      case 'rejected': return 'rgba(255, 0, 0, 0.2)';
      case 'pending': return 'rgba(255, 255, 0, 0.2)';
      case 'background': return 'rgba(0, 191, 255, 0.2)';
      default: return 'rgba(255, 255, 255, 0.2)';
    }
  }};
  color: ${props => {
    switch(props.status) {
      case 'approved': return '#00ff00';
      case 'rejected': return '#ff0000';
      case 'pending': return '#ffff00';
      case 'background': return '#00bfff';
      default: return '#ffffff';
    }
  }};
`;

const FilterPanel = styled.div`
  background-color: #333;
  padding: 15px;
  border-radius: 4px;
  margin-bottom: 20px;
  display: ${props => props.visible ? 'block' : 'none'};
`;

const FilterGroup = styled.div`
  margin-bottom: 15px;
`;

const FilterLabel = styled.div`
  margin-bottom: 5px;
  font-weight: bold;
  color: #ccc;
`;

const CheckboxGroup = styled.div`
  display: flex;
  gap: 15px;
`;

const CheckboxLabel = styled.label`
  display: flex;
  align-items: center;
  cursor: pointer;
  
  input {
    margin-right: 5px;
  }
`;

const VideoReviewContainer = styled.div`
  display: grid;
  grid-template-columns: 2fr 1fr;
  gap: 20px;
`;

const VideoPlayer = styled.div`
  background-color: #000;
  border-radius: 8px;
  overflow: hidden;
  
  video {
    width: 100%;
    height: 100%;
    object-fit: contain;
  }
`;

const ReviewPanel = styled.div`
  background-color: #333;
  border-radius: 8px;
  padding: 15px;
`;

const RatingSystem = styled.div`
  margin: 15px 0;
`;

const RatingLabel = styled.div`
  margin-bottom: 8px;
  font-weight: bold;
`;

const StarContainer = styled.div`
  display: flex;
  gap: 5px;
`;

const Star = styled.span`
  font-size: 24px;
  cursor: pointer;
  color: ${props => props.filled ? '#ffcc00' : '#555'};
  
  &:hover {
    color: #ffcc00;
  }
`;

const NoteTextarea = styled.textarea`
  width: 100%;
  height: 120px;
  background-color: #222;
  border: 1px solid #444;
  border-radius: 4px;
  padding: 10px;
  color: white;
  margin-top: 5px;
  
  &:focus {
    outline: none;
    border-color: var(--neon-red);
  }
`;

const GroupsContainer = styled.div`
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 20px;
`;

const GroupCard = styled.div`
  background-color: #333;
  border-radius: 8px;
  padding: 15px;
  border: 1px solid rgba(255, 0, 60, 0.3);
`;

const GroupTitle = styled.h3`
  color: var(--neon-red);
  margin-bottom: 10px;
  display: flex;
  justify-content: space-between;
  align-items: center;
`;

const GroupMembersList = styled.ul`
  list-style: none;
  padding: 0;
  margin: 0;
  max-height: 200px;
  overflow-y: auto;
`;

const GroupMember = styled.li`
  padding: 8px;
  border-bottom: 1px solid rgba(255, 255, 255, 0.1);
  display: flex;
  justify-content: space-between;
  align-items: center;
  
  &:last-child {
    border-bottom: none;
  }
`;

// Add these new styled components for Competition Management
const SettingCard = styled.div`
  background-color: #333;
  border-radius: 8px;
  padding: 15px;
  margin-bottom: 20px;
  border: 1px solid rgba(255, 0, 60, 0.3);
`;

const SettingTitle = styled.h3`
  color: var(--neon-red);
  margin-bottom: 15px;
  display: flex;
  justify-content: space-between;
  align-items: center;
`;

const FormGroup = styled.div`
  margin-bottom: 15px;
`;

const FormLabel = styled.label`
  display: block;
  margin-bottom: 8px;
  color: #ccc;
  font-weight: bold;
`;

const FormInput = styled.input`
  width: 100%;
  padding: 10px;
  background-color: #222;
  border: 1px solid #444;
  border-radius: 4px;
  color: white;
  
  &:focus {
    outline: none;
    border-color: var(--neon-red);
  }
`;

const FormSelect = styled.select`
  width: 100%;
  padding: 10px;
  background-color: #222;
  border: 1px solid #444;
  border-radius: 4px;
  color: white;
  
  &:focus {
    outline: none;
    border-color: var(--neon-red);
  }
`;

const FormTextarea = styled.textarea`
  width: 100%;
  padding: 10px;
  background-color: #222;
  border: 1px solid #444;
  border-radius: 4px;
  color: white;
  min-height: 100px;
  
  &:focus {
    outline: none;
    border-color: var(--neon-red);
  }
`;

const Schedule = styled.div`
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: 15px;
  margin-bottom: 15px;
`;

const ScheduleItem = styled.div`
  background-color: #222;
  padding: 12px;
  border-radius: 4px;
  border-left: 3px solid var(--neon-red);
`;

const ScheduleItemTitle = styled.div`
  font-weight: bold;
  margin-bottom: 5px;
`;

const ScheduleItemTime = styled.div`
  font-size: 0.9rem;
  color: #aaa;
`;

const PrizeTable = styled.table`
  width: 100%;
  border-collapse: collapse;
  
  th, td {
    padding: 10px 15px;
    text-align: left;
    border-bottom: 1px solid rgba(255, 255, 255, 0.1);
  }
  
  th {
    background-color: rgba(255, 0, 60, 0.1);
    color: var(--neon-red);
  }
`;

const CommunicationTemplate = styled.div`
  margin-bottom: 15px;
  background-color: #222;
  padding: 15px;
  border-radius: 4px;
  border-left: 3px solid ${props => props.color || 'var(--neon-red)'};
`;

const TemplateTitle = styled.div`
  font-weight: bold;
  margin-bottom: 8px;
  display: flex;
  justify-content: space-between;
`;

const TemplatePreview = styled.div`
  color: #ccc;
  font-size: 0.9rem;
  line-height: 1.4;
`;

// Add these new styled components for Analytics Dashboard
const StatCard = styled.div`
  background-color: #333;
  border-radius: 8px;
  padding: 15px;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  height: 100%;
`;

const StatValue = styled.div`
  font-size: 2.2rem;
  font-weight: bold;
  color: white;
  margin: 10px 0;
`;

const StatLabel = styled.div`
  color: #999;
  font-size: 0.9rem;
`;

const StatGrid = styled.div`
  display: grid;
  grid-template-columns: repeat(4, 1fr);
  gap: 20px;
  margin-bottom: 30px;
`;

const ChartContainer = styled.div`
  background-color: #333;
  border-radius: 8px;
  padding: 20px;
  margin-bottom: 20px;
  border: 1px solid rgba(255, 0, 60, 0.3);
  height: 350px;
  position: relative;
`;

const ChartTitle = styled.h3`
  color: var(--neon-red);
  margin-bottom: 20px;
  font-size: 1.2rem;
`;

const MapContainer = styled.div`
  height: 100%;
  background: url('/world-map-dark.png') center/contain no-repeat;
  position: relative;
`;

const HeatPoint = styled.div`
  position: absolute;
  width: ${props => props.size || 30}px;
  height: ${props => props.size || 30}px;
  border-radius: 50%;
  background-color: rgba(255, 0, 60, 0.7);
  box-shadow: 0 0 15px rgba(255, 0, 60, 0.5);
  transform: translate(-50%, -50%);
  opacity: ${props => props.intensity || 0.7};
  top: ${props => props.top}%;
  left: ${props => props.left}%;
`;

const ProgressBar = styled.div`
  height: 8px;
  background-color: #444;
  border-radius: 4px;
  overflow: hidden;
  margin-top: 5px;
`;

const Progress = styled.div`
  height: 100%;
  background-color: ${props => props.color || 'var(--neon-red)'};
  width: ${props => props.value || 0}%;
`;

const TabContainer = styled.div`
  display: flex;
  margin-bottom: 20px;
`;

const Tab = styled.div`
  padding: 10px 20px;
  background-color: ${props => props.active ? 'rgba(255, 0, 60, 0.3)' : '#333'};
  border-radius: 4px 4px 0 0;
  cursor: pointer;
  margin-right: 5px;
  
  &:hover {
    background-color: ${props => props.active ? 'rgba(255, 0, 60, 0.3)' : 'rgba(255, 0, 60, 0.1)'};
  }
`;

const MetricCard = styled.div`
  display: flex;
  justify-content: space-between;
  align-items: center;
  background-color: #333;
  padding: 15px;
  border-radius: 4px;
  margin-bottom: 15px;
`;

const MetricName = styled.div`
  font-weight: bold;
`;

const MetricValue = styled.div`
  font-size: 1.1rem;
  color: ${props => props.color || 'white'};
`;

// Add these new styled components for Content Management
const ContentGrid = styled.div`
  display: grid;
  grid-template-columns: 1fr 3fr;
  gap: 20px;
`;

const ContentSidebar = styled.div`
  background-color: #333;
  border-radius: 8px;
  padding: 15px;
`;

const ContentArea = styled.div`
  background-color: #333;
  border-radius: 8px;
  padding: 20px;
`;

const ContentNavItem = styled.div`
  padding: 10px 15px;
  cursor: pointer;
  border-radius: 4px;
  margin-bottom: 8px;
  background-color: ${props => props.active ? 'rgba(255, 0, 60, 0.3)' : 'transparent'};
  
  &:hover {
    background-color: ${props => props.active ? 'rgba(255, 0, 60, 0.3)' : 'rgba(255, 0, 60, 0.1)'};
  }
`;

const MediaGrid = styled.div`
  display: grid;
  grid-template-columns: repeat(4, 1fr);
  gap: 15px;
  margin-top: 20px;
`;

const MediaItem = styled.div`
  background-color: #222;
  border-radius: 4px;
  overflow: hidden;
  position: relative;
  aspect-ratio: 1 / 1;
  
  &:hover .media-actions {
    opacity: 1;
  }
`;

const MediaImage = styled.div`
  width: 100%;
  height: 100%;
  background-size: cover;
  background-position: center;
  background-image: url(${props => props.src});
`;

const MediaActions = styled.div`
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  background-color: rgba(0, 0, 0, 0.7);
  padding: 10px;
  display: flex;
  justify-content: space-between;
  opacity: 0;
  transition: opacity 0.2s ease;
`;

const DocumentItem = styled.div`
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 15px;
  background-color: #222;
  border-radius: 4px;
  margin-bottom: 10px;
`;

const DocumentInfo = styled.div`
  display: flex;
  align-items: center;
`;

const DocumentIcon = styled.div`
  width: 40px;
  height: 40px;
  background-color: #444;
  border-radius: 4px;
  display: flex;
  align-items: center;
  justify-content: center;
  margin-right: 15px;
  color: #ccc;
  font-weight: bold;
  font-size: 0.8rem;
`;

const DocumentMeta = styled.div`
  color: #999;
  font-size: 0.85rem;
  margin-top: 3px;
`;

const EditorContainer = styled.div`
  border: 1px solid #444;
  border-radius: 4px;
  overflow: hidden;
`;

const EditorToolbar = styled.div`
  background-color: #222;
  padding: 10px;
  border-bottom: 1px solid #444;
  display: flex;
  gap: 10px;
`;

const ToolbarButton = styled.button`
  background-color: #333;
  border: none;
  color: #ccc;
  padding: 5px 10px;
  border-radius: 4px;
  cursor: pointer;
  
  &:hover {
    background-color: #444;
  }
`;

const EditorContent = styled.div`
  background-color: #222;
  padding: 15px;
  min-height: 300px;
  color: white;
`;

// Mock data for demonstration
const mockParticipants = [
  { id: 1, name: 'John Doe', age: 32, status: 'pending', email: 'john@example.com', phone: '555-1234', videoRating: 3 },
  { id: 2, name: 'Jane Smith', age: 28, status: 'approved', email: 'jane@example.com', phone: '555-5678', videoRating: 5 },
  { id: 3, name: 'Michael Johnson', age: 35, status: 'background', email: 'michael@example.com', phone: '555-9012', videoRating: 4 },
  { id: 4, name: 'Emily Davis', age: 24, status: 'rejected', email: 'emily@example.com', phone: '555-3456', videoRating: 2 },
  { id: 5, name: 'Robert Wilson', age: 41, status: 'pending', email: 'robert@example.com', phone: '555-7890', videoRating: 3 },
  { id: 6, name: 'Sarah Brown', age: 29, status: 'background', email: 'sarah@example.com', phone: '555-4321', videoRating: 4 },
  { id: 7, name: 'David Miller', age: 33, status: 'approved', email: 'david@example.com', phone: '555-8765', videoRating: 5 }
];

const mockGroups = [
  { id: 1, name: 'Group A', members: [
    { id: 1, name: 'John Doe' },
    { id: 2, name: 'Jane Smith' }
  ]},
  { id: 2, name: 'Group B', members: [
    { id: 3, name: 'Michael Johnson' },
    { id: 6, name: 'Sarah Brown' }
  ]},
  { id: 3, name: 'Group C', members: [
    { id: 7, name: 'David Miller' }
  ]}
];

// Mock data for games
const mockGames = [
  { id: 1, name: 'Red Light, Green Light', duration: 30, maxPlayers: 100, difficulty: 'Hard' },
  { id: 2, name: 'Sugar Honeycomb', duration: 15, maxPlayers: 80, difficulty: 'Medium' },
  { id: 3, name: 'Tug of War', duration: 20, maxPlayers: 60, difficulty: 'Hard' },
  { id: 4, name: 'Marbles', duration: 45, maxPlayers: 40, difficulty: 'Medium' },
  { id: 5, name: 'Glass Bridge', duration: 30, maxPlayers: 20, difficulty: 'Extreme' },
  { id: 6, name: 'Squid Game', duration: 60, maxPlayers: 10, difficulty: 'Extreme' }
];

// Mock data for schedule
const mockSchedule = [
  { id: 1, title: 'Player Registration Deadline', date: '2023-08-15', time: '11:59 PM' },
  { id: 2, title: 'Game 1: Red Light, Green Light', date: '2023-09-01', time: '10:00 AM' },
  { id: 3, title: 'Game 2: Sugar Honeycomb', date: '2023-09-02', time: '2:00 PM' },
  { id: 4, title: 'Game 3: Tug of War', date: '2023-09-03', time: '1:00 PM' },
  { id: 5, title: 'Game 4: Marbles', date: '2023-09-04', time: '11:00 AM' },
  { id: 6, title: 'Game 5: Glass Bridge', date: '2023-09-05', time: '3:00 PM' },
  { id: 7, title: 'Game 6: Squid Game Final', date: '2023-09-06', time: '7:00 PM' },
  { id: 8, title: 'Award Ceremony', date: '2023-09-07', time: '8:00 PM' }
];

// Mock data for prize pool
const mockPrizes = [
  { position: 1, amount: 38600000, status: 'Pending' },
  { position: 2, amount: 100000, status: 'Pending' },
  { position: 3, amount: 50000, status: 'Pending' },
  { position: '4-10', amount: 10000, status: 'Pending' }
];

// Mock data for analytics
const mockAnalytics = {
  totalApplicants: 12847,
  newToday: 348,
  approvalRate: 26,
  conversionRate: 64,
  demographics: {
    age: [
      { name: '18-24', value: 35 },
      { name: '25-34', value: 42 },
      { name: '35-44', value: 15 },
      { name: '45+', value: 8 }
    ],
    gender: [
      { name: 'Male', value: 62 },
      { name: 'Female', value: 36 },
      { name: 'Non-binary', value: 2 }
    ]
  },
  reviewProgress: {
    totalReviewed: 8324,
    pendingReview: 4523,
    approved: 2895,
    rejected: 5429
  },
  socialMedia: {
    followers: {
      instagram: 245000,
      twitter: 189000,
      tiktok: 428000,
      facebook: 132000
    },
    engagement: {
      instagram: 8.3,
      twitter: 4.7,
      tiktok: 12.5,
      facebook: 3.2
    },
    growth: {
      instagram: 4.2,
      twitter: 2.8,
      tiktok: 15.3,
      facebook: 1.4
    }
  },
  geoDistribution: [
    { region: 'North America', count: 4532, percentage: 35.3 },
    { region: 'Europe', count: 3285, percentage: 25.6 },
    { region: 'Asia', count: 2984, percentage: 23.2 },
    { region: 'South America', count: 1023, percentage: 8.0 },
    { region: 'Oceania', count: 645, percentage: 5.0 },
    { region: 'Africa', count: 378, percentage: 2.9 }
  ],
  heatMapPoints: [
    { top: 30, left: 20, size: 40, intensity: 0.9 }, // North America
    { top: 28, left: 48, size: 30, intensity: 0.7 }, // Europe
    { top: 40, left: 70, size: 35, intensity: 0.8 }, // Asia
    { top: 65, left: 30, size: 20, intensity: 0.6 }, // South America
    { top: 65, left: 80, size: 15, intensity: 0.5 }, // Oceania
    { top: 45, left: 50, size: 10, intensity: 0.4 }  // Africa
  ]
};

// Mock data for content management
const mockContent = {
  pages: [
    { id: 1, title: 'Home Page', lastUpdated: '2023-07-15' },
    { id: 2, title: 'Rules & Guidelines', lastUpdated: '2023-07-28' },
    { id: 3, title: 'FAQ', lastUpdated: '2023-08-02' },
    { id: 4, title: 'Registration', lastUpdated: '2023-07-10' },
    { id: 5, title: 'About', lastUpdated: '2023-06-25' }
  ],
  media: [
    { id: 1, name: 'hero-image.jpg', type: 'image', url: 'https://via.placeholder.com/300', size: '1.2 MB', uploaded: '2023-07-05' },
    { id: 2, name: 'trailer.mp4', type: 'video', url: 'https://via.placeholder.com/300', size: '24.5 MB', uploaded: '2023-07-12' },
    { id: 3, name: 'logo.png', type: 'image', url: 'https://via.placeholder.com/300', size: '0.8 MB', uploaded: '2023-06-20' },
    { id: 4, name: 'poster.jpg', type: 'image', url: 'https://via.placeholder.com/300', size: '2.3 MB', uploaded: '2023-07-18' },
    { id: 5, name: 'player-mask.png', type: 'image', url: 'https://via.placeholder.com/300', size: '1.5 MB', uploaded: '2023-07-25' },
    { id: 6, name: 'background.jpg', type: 'image', url: 'https://via.placeholder.com/300', size: '3.1 MB', uploaded: '2023-06-28' },
    { id: 7, name: 'intro.mp4', type: 'video', url: 'https://via.placeholder.com/300', size: '18.7 MB', uploaded: '2023-07-08' },
    { id: 8, name: 'teaser.mp4', type: 'video', url: 'https://via.placeholder.com/300', size: '12.3 MB', uploaded: '2023-08-01' }
  ],
  emailTemplates: [
    { id: 1, name: 'Welcome Email', subject: 'Welcome to Squid Game 2', lastUpdated: '2023-07-10' },
    { id: 2, name: 'Registration Confirmation', subject: 'Your Registration is Confirmed', lastUpdated: '2023-07-12' },
    { id: 3, name: 'Application Status', subject: 'Your Squid Game 2 Application Status', lastUpdated: '2023-07-15' },
    { id: 4, name: 'Selection Notification', subject: 'Congratulations! You\'ve Been Selected', lastUpdated: '2023-07-20' },
    { id: 5, name: 'Rejection Notice', subject: 'Squid Game 2 Application Update', lastUpdated: '2023-07-20' }
  ],
  legalDocuments: [
    { id: 1, name: 'Player Agreement', type: 'PDF', size: '1.2 MB', updated: '2023-07-05', version: '1.2' },
    { id: 2, name: 'Liability Waiver', type: 'PDF', size: '0.8 MB', updated: '2023-07-10', version: '1.1' },
    { id: 3, name: 'Medical Release Form', type: 'PDF', size: '0.5 MB', updated: '2023-07-15', version: '1.0' },
    { id: 4, name: 'Confidentiality Agreement', type: 'PDF', size: '0.7 MB', updated: '2023-06-25', version: '1.3' },
    { id: 5, name: 'Terms & Conditions', type: 'PDF', size: '1.5 MB', updated: '2023-07-01', version: '2.1' },
    { id: 6, name: 'Privacy Policy', type: 'PDF', size: '0.9 MB', updated: '2023-07-01', version: '1.4' }
  ]
};

const AdminDashboard = ({ onLogout }) => {
  const [activeSection, setActiveSection] = useState('participants');
  const [showFilters, setShowFilters] = useState(false);
  const [selectedParticipant, setSelectedParticipant] = useState(null);
  const [searchTerm, setSearchTerm] = useState('');
  const [filters, setFilters] = useState({
    status: {
      pending: true,
      approved: true,
      rejected: true,
      background: true
    }
  });
  const [ratings, setRatings] = useState({
    creativity: 0,
    personality: 0,
    potential: 0
  });
  
  // Add new state variables for Analytics
  const [activeAnalyticsTab, setActiveAnalyticsTab] = useState('overview');
  
  // Add new state variables for Content Management
  const [activeContentSection, setActiveContentSection] = useState('website');
  // Keep the state variable since it's used in the UI, but declare it without the unused setter
  const activePageContent = '# Rules & Guidelines\n\n## Game Overview\n\nWelcome to Squid Game 2. This competition consists of a series of six games, each designed to test different skills and abilities.\n\n## Eligibility\n\n- Participants must be at least 18 years of age\n- Participants must pass a physical examination\n- Participants must sign all required legal documents\n\n## Prize Structure\n\nThe total prize pool is $45,000,000, distributed as follows:\n\n- 1st Place: $38,600,000\n- 2nd Place: $100,000\n- 3rd Place: $50,000\n- 4th-10th Place: $10,000 each';
  
  const handleRatingChange = (category, value) => {
    setRatings({
      ...ratings,
      [category]: value
    });
  };
  
  const toggleFilter = (category, value) => {
    setFilters({
      ...filters,
      [category]: {
        ...filters[category],
        [value]: !filters[category][value]
      }
    });
  };
  
  const filteredParticipants = mockParticipants.filter(participant => {
    // Search filter
    const matchesSearch = participant.name.toLowerCase().includes(searchTerm.toLowerCase()) ||
                         participant.email.toLowerCase().includes(searchTerm.toLowerCase());
    
    // Status filter
    const matchesStatus = filters.status[participant.status];
    
    return matchesSearch && matchesStatus;
  });
  
  const renderContent = () => {
    switch(activeSection) {
      case 'participants':
        return (
          <>
            <SectionTitle>Participant Management</SectionTitle>
            <SearchContainer>
              <SearchInput 
                type="text" 
                placeholder="Search participants..." 
                value={searchTerm}
                onChange={(e) => setSearchTerm(e.target.value)}
              />
              <FilterButton onClick={() => setShowFilters(!showFilters)}>
                {showFilters ? 'Hide Filters' : 'Show Filters'}
              </FilterButton>
            </SearchContainer>
            
            <FilterPanel visible={showFilters}>
              <FilterGroup>
                <FilterLabel>Status</FilterLabel>
                <CheckboxGroup>
                  <CheckboxLabel>
                    <input 
                      type="checkbox" 
                      checked={filters.status.pending}
                      onChange={() => toggleFilter('status', 'pending')}
                    />
                    Pending
                  </CheckboxLabel>
                  <CheckboxLabel>
                    <input 
                      type="checkbox" 
                      checked={filters.status.approved}
                      onChange={() => toggleFilter('status', 'approved')}
                    />
                    Approved
                  </CheckboxLabel>
                  <CheckboxLabel>
                    <input 
                      type="checkbox" 
                      checked={filters.status.rejected}
                      onChange={() => toggleFilter('status', 'rejected')}
                    />
                    Rejected
                  </CheckboxLabel>
                  <CheckboxLabel>
                    <input 
                      type="checkbox" 
                      checked={filters.status.background}
                      onChange={() => toggleFilter('status', 'background')}
                    />
                    Background Check
                  </CheckboxLabel>
                </CheckboxGroup>
              </FilterGroup>
            </FilterPanel>
            
            <ParticipantTable>
              <thead>
                <tr>
                  <th>Name</th>
                  <th>Age</th>
                  <th>Contact</th>
                  <th>Status</th>
                  <th>Video Rating</th>
                  <th>Actions</th>
                </tr>
              </thead>
              <tbody>
                {filteredParticipants.map(participant => (
                  <tr key={participant.id}>
                    <td>{participant.name}</td>
                    <td>{participant.age}</td>
                    <td>
                      <div>{participant.email}</div>
                      <div>{participant.phone}</div>
                    </td>
                    <td>
                      <StatusBadge status={participant.status}>
                        {participant.status.charAt(0).toUpperCase() + participant.status.slice(1)}
                      </StatusBadge>
                    </td>
                    <td>{'⭐'.repeat(participant.videoRating)}</td>
                    <td>
                      <ActionButton onClick={() => {
                        setSelectedParticipant(participant);
                        setActiveSection('videoReview');
                      }}>
                        Review
                      </ActionButton>
                      <ActionButton secondary>
                        Verify
                      </ActionButton>
                    </td>
                  </tr>
                ))}
              </tbody>
            </ParticipantTable>
          </>
        );
        
      case 'videoReview':
        return (
          <>
            <SectionTitle>
              Video Review - {selectedParticipant ? selectedParticipant.name : ''}
              <ActionButton secondary onClick={() => setActiveSection('participants')}>
                Back to List
              </ActionButton>
            </SectionTitle>
            <VideoReviewContainer>
              <VideoPlayer>
                <video controls>
                  <source src="/sample-video.mp4" type="video/mp4" />
                  Your browser does not support the video tag.
                </video>
              </VideoPlayer>
              <ReviewPanel>
                <h3>Review Form</h3>
                
                <RatingSystem>
                  <RatingLabel>Creativity</RatingLabel>
                  <StarContainer>
                    {[1, 2, 3, 4, 5].map(star => (
                      <Star 
                        key={star} 
                        filled={star <= ratings.creativity}
                        onClick={() => handleRatingChange('creativity', star)}
                      >
                        ★
                      </Star>
                    ))}
                  </StarContainer>
                </RatingSystem>
                
                <RatingSystem>
                  <RatingLabel>Personality</RatingLabel>
                  <StarContainer>
                    {[1, 2, 3, 4, 5].map(star => (
                      <Star 
                        key={star} 
                        filled={star <= ratings.personality}
                        onClick={() => handleRatingChange('personality', star)}
                      >
                        ★
                      </Star>
                    ))}
                  </StarContainer>
                </RatingSystem>
                
                <RatingSystem>
                  <RatingLabel>Potential for Show</RatingLabel>
                  <StarContainer>
                    {[1, 2, 3, 4, 5].map(star => (
                      <Star 
                        key={star} 
                        filled={star <= ratings.potential}
                        onClick={() => handleRatingChange('potential', star)}
                      >
                        ★
                      </Star>
                    ))}
                  </StarContainer>
                </RatingSystem>
                
                <div>
                  <RatingLabel>Notes</RatingLabel>
                  <NoteTextarea placeholder="Enter your notes about the applicant here..." />
                </div>
                
                <div style={{ marginTop: '20px', display: 'flex', gap: '10px' }}>
                  <ActionButton>Approve</ActionButton>
                  <ActionButton secondary>Reject</ActionButton>
                  <ActionButton secondary>Request More Info</ActionButton>
                </div>
              </ReviewPanel>
            </VideoReviewContainer>
          </>
        );
        
      case 'backgroundCheck':
        return (
          <>
            <SectionTitle>Background Check Tools</SectionTitle>
            <div style={{ display: 'grid', gridTemplateColumns: '1fr 1fr', gap: '20px' }}>
              <div>
                <h3>Verification Queue</h3>
                <ParticipantTable>
                  <thead>
                    <tr>
                      <th>Name</th>
                      <th>Status</th>
                      <th>Actions</th>
                    </tr>
                  </thead>
                  <tbody>
                    {mockParticipants
                      .filter(p => p.status === 'background')
                      .map(participant => (
                        <tr key={participant.id}>
                          <td>{participant.name}</td>
                          <td>
                            <StatusBadge status={participant.status}>
                              Background Check
                            </StatusBadge>
                          </td>
                          <td>
                            <ActionButton>Verify</ActionButton>
                            <ActionButton secondary>Reject</ActionButton>
                          </td>
                        </tr>
                      ))
                    }
                  </tbody>
                </ParticipantTable>
              </div>
              <div>
                <h3>Verification Tools</h3>
                <div style={{ backgroundColor: '#333', padding: '15px', borderRadius: '8px' }}>
                  <div style={{ marginBottom: '15px' }}>
                    <FilterLabel>ID Verification</FilterLabel>
                    <ActionButton>Upload ID Scan</ActionButton>
                    <ActionButton secondary>Request ID</ActionButton>
                  </div>
                  
                  <div style={{ marginBottom: '15px' }}>
                    <FilterLabel>Background Check Services</FilterLabel>
                    <ActionButton>Run Criminal Check</ActionButton>
                    <ActionButton>Employment Verification</ActionButton>
                  </div>
                  
                  <div>
                    <FilterLabel>Health Check</FilterLabel>
                    <ActionButton>Request Medical Clearance</ActionButton>
                    <ActionButton secondary>Upload Medical Records</ActionButton>
                  </div>
                </div>
              </div>
            </div>
          </>
        );
        
      case 'selection':
        return (
          <>
            <SectionTitle>Contestant Selection & Grouping</SectionTitle>
            <div style={{ marginBottom: '20px', display: 'flex', gap: '10px' }}>
              <ActionButton>Create New Group</ActionButton>
              <ActionButton secondary>Auto-Generate Groups</ActionButton>
            </div>
            
            <GroupsContainer>
              {mockGroups.map(group => (
                <GroupCard key={group.id}>
                  <GroupTitle>
                    {group.name}
                    <span>{group.members.length} members</span>
                  </GroupTitle>
                  <GroupMembersList>
                    {group.members.map(member => (
                      <GroupMember key={member.id}>
                        {member.name}
                        <ActionButton secondary style={{ padding: '2px 5px', fontSize: '0.8rem' }}>
                          Remove
                        </ActionButton>
                      </GroupMember>
                    ))}
                  </GroupMembersList>
                  <div style={{ marginTop: '15px' }}>
                    <ActionButton style={{ width: '100%' }}>Add Participant</ActionButton>
                  </div>
                </GroupCard>
              ))}
            </GroupsContainer>
          </>
        );
        
      case 'competition':
        return (
          <>
            <SectionTitle>Competition Management</SectionTitle>
            
            {/* Game Configuration */}
            <SettingCard>
              <SettingTitle>Game Configuration Settings</SettingTitle>
              <div style={{ display: 'grid', gridTemplateColumns: '1fr 1fr', gap: '20px' }}>
                <div>
                  <FormGroup>
                    <FormLabel>Active Game</FormLabel>
                    <FormSelect>
                      <option value="">Select a game...</option>
                      {mockGames.map(game => (
                        <option key={game.id} value={game.id}>
                          {game.name}
                        </option>
                      ))}
                    </FormSelect>
                  </FormGroup>
                  
                  <FormGroup>
                    <FormLabel>Game Duration (minutes)</FormLabel>
                    <FormInput type="number" defaultValue="30" />
                  </FormGroup>
                  
                  <FormGroup>
                    <FormLabel>Maximum Players</FormLabel>
                    <FormInput type="number" defaultValue="100" />
                  </FormGroup>
                </div>
                
                <div>
                  <FormGroup>
                    <FormLabel>Difficulty Level</FormLabel>
                    <FormSelect defaultValue="Hard">
                      <option value="Easy">Easy</option>
                      <option value="Medium">Medium</option>
                      <option value="Hard">Hard</option>
                      <option value="Extreme">Extreme</option>
                    </FormSelect>
                  </FormGroup>
                  
                  <FormGroup>
                    <FormLabel>Elimination Percentage</FormLabel>
                    <FormInput type="number" defaultValue="50" />
                  </FormGroup>
                  
                  <FormGroup>
                    <FormLabel>Special Rules</FormLabel>
                    <FormTextarea placeholder="Enter any special rules for this game..." />
                  </FormGroup>
                </div>
              </div>
              
              <div style={{ marginTop: '20px' }}>
                <ActionButton>Save Game Configuration</ActionButton>
                <ActionButton secondary style={{ marginLeft: '10px' }}>Reset</ActionButton>
              </div>
            </SettingCard>
            
            {/* Event Scheduling */}
            <SettingCard>
              <SettingTitle>
                Event Scheduling & Logistics
                <ActionButton secondary>Add Event</ActionButton>
              </SettingTitle>
              
              <Schedule>
                {mockSchedule.map(event => (
                  <ScheduleItem key={event.id}>
                    <ScheduleItemTitle>{event.title}</ScheduleItemTitle>
                    <ScheduleItemTime>{event.date} at {event.time}</ScheduleItemTime>
                    <div style={{ marginTop: '10px', display: 'flex', gap: '5px' }}>
                      <ActionButton style={{ padding: '3px 8px', fontSize: '0.8rem' }}>Edit</ActionButton>
                      <ActionButton secondary style={{ padding: '3px 8px', fontSize: '0.8rem' }}>Remove</ActionButton>
                    </div>
                  </ScheduleItem>
                ))}
              </Schedule>
              
              <div style={{ marginTop: '15px' }}>
                <FormGroup>
                  <FormLabel>Location Details</FormLabel>
                  <FormTextarea defaultValue="Undisclosed island location. Coordinates and access instructions to be provided to staff only." />
                </FormGroup>
                
                <div style={{ display: 'flex', gap: '15px' }}>
                  <FormGroup style={{ flex: 1 }}>
                    <FormLabel>Security Personnel</FormLabel>
                    <FormInput type="number" defaultValue="100" />
                  </FormGroup>
                  
                  <FormGroup style={{ flex: 1 }}>
                    <FormLabel>Medical Staff</FormLabel>
                    <FormInput type="number" defaultValue="30" />
                  </FormGroup>
                  
                  <FormGroup style={{ flex: 1 }}>
                    <FormLabel>Support Staff</FormLabel>
                    <FormInput type="number" defaultValue="50" />
                  </FormGroup>
                </div>
              </div>
            </SettingCard>
            
            {/* Prize Pool Management */}
            <SettingCard>
              <SettingTitle>Prize Pool Management</SettingTitle>
              
              <FormGroup>
                <FormLabel>Total Prize Pool</FormLabel>
                <FormInput type="number" defaultValue="45000000" />
              </FormGroup>
              
              <PrizeTable>
                <thead>
                  <tr>
                    <th>Position</th>
                    <th>Prize Amount ($)</th>
                    <th>Status</th>
                    <th>Actions</th>
                  </tr>
                </thead>
                <tbody>
                  {mockPrizes.map((prize, index) => (
                    <tr key={index}>
                      <td>{typeof prize.position === 'string' ? prize.position : `${prize.position}${getOrdinalSuffix(prize.position)} Place`}</td>
                      <td>${prize.amount.toLocaleString()}</td>
                      <td>{prize.status}</td>
                      <td>
                        <ActionButton style={{ padding: '3px 8px', fontSize: '0.8rem' }}>Edit</ActionButton>
                      </td>
                    </tr>
                  ))}
                </tbody>
              </PrizeTable>
              
              <div style={{ marginTop: '15px' }}>
                <ActionButton>Update Prize Pool</ActionButton>
                <ActionButton secondary style={{ marginLeft: '10px' }}>Add Prize Tier</ActionButton>
              </div>
            </SettingCard>
            
            {/* Contestant Communication */}
            <SettingCard>
              <SettingTitle>Contestant Communication System</SettingTitle>
              
              <div style={{ marginBottom: '20px' }}>
                <FormGroup>
                  <FormLabel>Message All Contestants</FormLabel>
                  <FormTextarea placeholder="Enter message to send to all contestants..." />
                </FormGroup>
                
                <div style={{ display: 'flex', gap: '10px' }}>
                  <FormGroup style={{ flex: 1 }}>
                    <FormLabel>Priority</FormLabel>
                    <FormSelect defaultValue="Medium">
                      <option value="Low">Low</option>
                      <option value="Medium">Medium</option>
                      <option value="High">High</option>
                      <option value="Urgent">Urgent</option>
                    </FormSelect>
                  </FormGroup>
                  
                  <FormGroup style={{ flex: 1 }}>
                    <FormLabel>Delivery Method</FormLabel>
                    <FormSelect defaultValue="Both">
                      <option value="Email">Email</option>
                      <option value="SMS">SMS</option>
                      <option value="Both">Both Email & SMS</option>
                    </FormSelect>
                  </FormGroup>
                </div>
                
                <ActionButton style={{ marginTop: '10px' }}>Send Message</ActionButton>
              </div>
              
              <div>
                <SettingTitle style={{ fontSize: '1rem' }}>Message Templates</SettingTitle>
                
                <CommunicationTemplate color="#00cc00">
                  <TemplateTitle>
                    Acceptance Notification
                    <ActionButton style={{ padding: '3px 8px', fontSize: '0.8rem' }}>Edit</ActionButton>
                  </TemplateTitle>
                  <TemplatePreview>
                    Congratulations! You have been selected to participate in Squid Game 2. Further instructions will follow. Prepare for a life-changing experience.
                  </TemplatePreview>
                </CommunicationTemplate>
                
                <CommunicationTemplate color="#cc0000">
                  <TemplateTitle>
                    Rejection Notification
                    <ActionButton style={{ padding: '3px 8px', fontSize: '0.8rem' }}>Edit</ActionButton>
                  </TemplateTitle>
                  <TemplatePreview>
                    Thank you for your interest in Squid Game 2. Unfortunately, you have not been selected to participate at this time. We appreciate your enthusiasm.
                  </TemplatePreview>
                </CommunicationTemplate>
                
                <CommunicationTemplate>
                  <TemplateTitle>
                    Game Instructions
                    <ActionButton style={{ padding: '3px 8px', fontSize: '0.8rem' }}>Edit</ActionButton>
                  </TemplateTitle>
                  <TemplatePreview>
                    [GAME_NAME] will begin on [DATE] at [TIME]. Please follow all instructions carefully. Remember: When the music stops, you must stop moving immediately.
                  </TemplatePreview>
                </CommunicationTemplate>
                
                <ActionButton secondary style={{ marginTop: '10px' }}>Add New Template</ActionButton>
              </div>
            </SettingCard>
          </>
        );
        
      case 'analytics':
        return (
          <>
            <SectionTitle>Analytics Dashboard</SectionTitle>
            
            <StatGrid>
              <StatCard>
                <StatLabel>Total Applicants</StatLabel>
                <StatValue>{mockAnalytics.totalApplicants.toLocaleString()}</StatValue>
                <div style={{ color: 'green', fontSize: '0.9rem' }}>
                  +{mockAnalytics.newToday} today
                </div>
              </StatCard>
              
              <StatCard>
                <StatLabel>Approval Rate</StatLabel>
                <StatValue>{mockAnalytics.approvalRate}%</StatValue>
                <ProgressBar>
                  <Progress value={mockAnalytics.approvalRate} color="#00cc00" />
                </ProgressBar>
              </StatCard>
              
              <StatCard>
                <StatLabel>Registration Conversion</StatLabel>
                <StatValue>{mockAnalytics.conversionRate}%</StatValue>
                <ProgressBar>
                  <Progress value={mockAnalytics.conversionRate} />
                </ProgressBar>
              </StatCard>
              
              <StatCard>
                <StatLabel>Total Social Followers</StatLabel>
                <StatValue>
                  {Object.values(mockAnalytics.socialMedia.followers).reduce((a, b) => a + b, 0).toLocaleString()}
                </StatValue>
                <div style={{ color: 'green', fontSize: '0.9rem' }}>
                  +{Math.round(Object.values(mockAnalytics.socialMedia.growth).reduce((a, b) => a + b, 0))}% this week
                </div>
              </StatCard>
            </StatGrid>
            
            <TabContainer>
              <Tab 
                active={activeAnalyticsTab === 'overview'} 
                onClick={() => setActiveAnalyticsTab('overview')}
              >
                Overview
              </Tab>
              <Tab 
                active={activeAnalyticsTab === 'demographics'} 
                onClick={() => setActiveAnalyticsTab('demographics')}
              >
                Demographics
              </Tab>
              <Tab 
                active={activeAnalyticsTab === 'social'} 
                onClick={() => setActiveAnalyticsTab('social')}
              >
                Social Media
              </Tab>
              <Tab 
                active={activeAnalyticsTab === 'geographical'} 
                onClick={() => setActiveAnalyticsTab('geographical')}
              >
                Geographical
              </Tab>
            </TabContainer>
            
            {activeAnalyticsTab === 'overview' && (
              <>
                <div style={{ display: 'grid', gridTemplateColumns: '1fr 1fr', gap: '20px' }}>
                  <ChartContainer>
                    <ChartTitle>Registration Trend (Last 30 Days)</ChartTitle>
                    <div style={{ display: 'flex', alignItems: 'flex-end', height: '250px', paddingTop: '20px' }}>
                      {/* Simplified bar chart */}
                      {Array.from({ length: 30 }, (_, i) => (
                        <div 
                          key={i} 
                          style={{
                            height: `${Math.random() * 80 + 20}%`,
                            flex: 1,
                            backgroundColor: 'rgba(255, 0, 60, 0.7)',
                            margin: '0 1px',
                            borderRadius: '3px 3px 0 0'
                          }}
                        />
                      ))}
                    </div>
                  </ChartContainer>
                  
                  <ChartContainer>
                    <ChartTitle>Application Review Progress</ChartTitle>
                    <div style={{ padding: '20px' }}>
                      <div style={{ marginBottom: '25px' }}>
                        <div style={{ display: 'flex', justifyContent: 'space-between', marginBottom: '8px' }}>
                          <div>Total Reviewed</div>
                          <div>{mockAnalytics.reviewProgress.totalReviewed} / {mockAnalytics.totalApplicants}</div>
                        </div>
                        <ProgressBar>
                          <Progress value={(mockAnalytics.reviewProgress.totalReviewed / mockAnalytics.totalApplicants) * 100} />
                        </ProgressBar>
                      </div>
                      
                      <div style={{ marginBottom: '25px' }}>
                        <div style={{ display: 'flex', justifyContent: 'space-between', marginBottom: '8px' }}>
                          <div>Approved</div>
                          <div>{mockAnalytics.reviewProgress.approved}</div>
                        </div>
                        <ProgressBar>
                          <Progress color="#00cc00" value={(mockAnalytics.reviewProgress.approved / mockAnalytics.totalApplicants) * 100} />
                        </ProgressBar>
                      </div>
                      
                      <div style={{ marginBottom: '25px' }}>
                        <div style={{ display: 'flex', justifyContent: 'space-between', marginBottom: '8px' }}>
                          <div>Rejected</div>
                          <div>{mockAnalytics.reviewProgress.rejected}</div>
                        </div>
                        <ProgressBar>
                          <Progress color="#cc0000" value={(mockAnalytics.reviewProgress.rejected / mockAnalytics.totalApplicants) * 100} />
                        </ProgressBar>
                      </div>
                      
                      <div>
                        <div style={{ display: 'flex', justifyContent: 'space-between', marginBottom: '8px' }}>
                          <div>Pending Review</div>
                          <div>{mockAnalytics.reviewProgress.pendingReview}</div>
                        </div>
                        <ProgressBar>
                          <Progress color="#cccc00" value={(mockAnalytics.reviewProgress.pendingReview / mockAnalytics.totalApplicants) * 100} />
                        </ProgressBar>
                      </div>
                    </div>
                  </ChartContainer>
                </div>
              </>
            )}
            
            {activeAnalyticsTab === 'demographics' && (
              <div style={{ display: 'grid', gridTemplateColumns: '1fr 1fr', gap: '20px' }}>
                <ChartContainer>
                  <ChartTitle>Age Distribution</ChartTitle>
                  <div style={{ display: 'flex', height: '250px', alignItems: 'flex-end', justifyContent: 'space-around', padding: '20px' }}>
                    {mockAnalytics.demographics.age.map(item => (
                      <div key={item.name} style={{ textAlign: 'center', width: '60px' }}>
                        <div 
                          style={{ 
                            height: `${item.value * 2}%`, 
                            backgroundColor: 'rgba(255, 0, 60, 0.7)',
                            borderRadius: '3px 3px 0 0',
                            marginBottom: '10px'
                          }} 
                        />
                        <div>{item.name}</div>
                        <div style={{ color: '#999', fontSize: '0.9rem' }}>{item.value}%</div>
                      </div>
                    ))}
                  </div>
                </ChartContainer>
                
                <ChartContainer>
                  <ChartTitle>Gender Distribution</ChartTitle>
                  <div style={{ height: '250px', display: 'flex', alignItems: 'center', justifyContent: 'center' }}>
                    <div style={{ position: 'relative', width: '200px', height: '200px' }}>
                      {/* Simplified pie chart */}
                      <svg width="200" height="200" viewBox="0 0 100 100">
                        <circle r="25" cx="50" cy="50" fill="rgba(255, 0, 60, 0.7)" stroke="#222" strokeWidth="1" />
                        <path d="M50,50 L50,25 A25,25 0 0,1 71,61 z" fill="rgba(0, 204, 255, 0.7)" stroke="#222" strokeWidth="1" />
                        <path d="M50,50 L71,61 A25,25 0 0,1 50,75 z" fill="rgba(204, 204, 0, 0.7)" stroke="#222" strokeWidth="1" />
                      </svg>
                    </div>
                    <div style={{ marginLeft: '20px' }}>
                      {mockAnalytics.demographics.gender.map(item => (
                        <div key={item.name} style={{ display: 'flex', alignItems: 'center', marginBottom: '10px' }}>
                          <div 
                            style={{ 
                              width: '12px', 
                              height: '12px', 
                              borderRadius: '50%', 
                              backgroundColor: item.name === 'Male' 
                                ? 'rgba(255, 0, 60, 0.7)' 
                                : item.name === 'Female' 
                                  ? 'rgba(0, 204, 255, 0.7)' 
                                  : 'rgba(204, 204, 0, 0.7)',
                              marginRight: '8px'
                            }} 
                          />
                          <div style={{ marginRight: '8px' }}>{item.name}</div>
                          <div style={{ color: '#999' }}>{item.value}%</div>
                        </div>
                      ))}
                    </div>
                  </div>
                </ChartContainer>
              </div>
            )}
            
            {activeAnalyticsTab === 'social' && (
              <>
                <div style={{ display: 'grid', gridTemplateColumns: 'repeat(4, 1fr)', gap: '20px', marginBottom: '20px' }}>
                  <StatCard>
                    <StatLabel>Instagram</StatLabel>
                    <StatValue>{mockAnalytics.socialMedia.followers.instagram.toLocaleString()}</StatValue>
                    <div style={{ color: 'green', fontSize: '0.9rem' }}>
                      +{mockAnalytics.socialMedia.growth.instagram}% growth
                    </div>
                  </StatCard>
                  
                  <StatCard>
                    <StatLabel>Twitter</StatLabel>
                    <StatValue>{mockAnalytics.socialMedia.followers.twitter.toLocaleString()}</StatValue>
                    <div style={{ color: 'green', fontSize: '0.9rem' }}>
                      +{mockAnalytics.socialMedia.growth.twitter}% growth
                    </div>
                  </StatCard>
                  
                  <StatCard>
                    <StatLabel>TikTok</StatLabel>
                    <StatValue>{mockAnalytics.socialMedia.followers.tiktok.toLocaleString()}</StatValue>
                    <div style={{ color: 'green', fontSize: '0.9rem' }}>
                      +{mockAnalytics.socialMedia.growth.tiktok}% growth
                    </div>
                  </StatCard>
                  
                  <StatCard>
                    <StatLabel>Facebook</StatLabel>
                    <StatValue>{mockAnalytics.socialMedia.followers.facebook.toLocaleString()}</StatValue>
                    <div style={{ color: 'green', fontSize: '0.9rem' }}>
                      +{mockAnalytics.socialMedia.growth.facebook}% growth
                    </div>
                  </StatCard>
                </div>
                
                <ChartContainer>
                  <ChartTitle>Engagement Metrics</ChartTitle>
                  <div style={{ padding: '20px' }}>
                    <MetricCard>
                      <MetricName>Instagram Engagement Rate</MetricName>
                      <MetricValue color="#00cc00">{mockAnalytics.socialMedia.engagement.instagram}%</MetricValue>
                    </MetricCard>
                    
                    <MetricCard>
                      <MetricName>Twitter Engagement Rate</MetricName>
                      <MetricValue color="#00cc00">{mockAnalytics.socialMedia.engagement.twitter}%</MetricValue>
                    </MetricCard>
                    
                    <MetricCard>
                      <MetricName>TikTok Engagement Rate</MetricName>
                      <MetricValue color="#00cc00">{mockAnalytics.socialMedia.engagement.tiktok}%</MetricValue>
                    </MetricCard>
                    
                    <MetricCard>
                      <MetricName>Facebook Engagement Rate</MetricName>
                      <MetricValue color="#00cc00">{mockAnalytics.socialMedia.engagement.facebook}%</MetricValue>
                    </MetricCard>
                  </div>
                </ChartContainer>
              </>
            )}
            
            {activeAnalyticsTab === 'geographical' && (
              <>
                <div style={{ display: 'grid', gridTemplateColumns: '2fr 1fr', gap: '20px' }}>
                  <ChartContainer style={{ height: '500px' }}>
                    <ChartTitle>Geographic Distribution Heatmap</ChartTitle>
                    <MapContainer>
                      {mockAnalytics.heatMapPoints.map((point, index) => (
                        <HeatPoint 
                          key={index}
                          top={point.top}
                          left={point.left}
                          size={point.size}
                          intensity={point.intensity}
                        />
                      ))}
                    </MapContainer>
                  </ChartContainer>
                  
                  <div>
                    <ChartContainer>
                      <ChartTitle>Regional Distribution</ChartTitle>
                      <div style={{ padding: '20px' }}>
                        {mockAnalytics.geoDistribution.map(region => (
                          <div key={region.region} style={{ marginBottom: '15px' }}>
                            <div style={{ display: 'flex', justifyContent: 'space-between', marginBottom: '5px' }}>
                              <div>{region.region}</div>
                              <div>{region.percentage}%</div>
                            </div>
                            <ProgressBar>
                              <Progress value={region.percentage} />
                            </ProgressBar>
                          </div>
                        ))}
                      </div>
                    </ChartContainer>
                  </div>
                </div>
              </>
            )}
          </>
        );
        
      case 'content':
        return (
          <>
            <SectionTitle>Content Management</SectionTitle>
            
            <ContentGrid>
              <ContentSidebar>
                <ContentNavItem 
                  active={activeContentSection === 'website'} 
                  onClick={() => setActiveContentSection('website')}
                >
                  Website Content
                </ContentNavItem>
                <ContentNavItem 
                  active={activeContentSection === 'media'} 
                  onClick={() => setActiveContentSection('media')}
                >
                  Media Library
                </ContentNavItem>
                <ContentNavItem 
                  active={activeContentSection === 'email'} 
                  onClick={() => setActiveContentSection('email')}
                >
                  Email Templates
                </ContentNavItem>
                <ContentNavItem 
                  active={activeContentSection === 'legal'} 
                  onClick={() => setActiveContentSection('legal')}
                >
                  Legal Documents
                </ContentNavItem>
              </ContentSidebar>
              
              <ContentArea>
                {activeContentSection === 'website' && (
                  <>
                    <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center', marginBottom: '20px' }}>
                      <FormGroup style={{ flex: 1, marginRight: '20px', marginBottom: 0 }}>
                        <FormLabel>Select Page</FormLabel>
                        <FormSelect defaultValue="2">
                          {mockContent.pages.map(page => (
                            <option key={page.id} value={page.id}>{page.title}</option>
                          ))}
                        </FormSelect>
                      </FormGroup>
                      <div>
                        <ActionButton>Publish Changes</ActionButton>
                        <ActionButton secondary style={{ marginLeft: '10px' }}>Preview</ActionButton>
                      </div>
                    </div>
                    
                    <EditorContainer>
                      <EditorToolbar>
                        <ToolbarButton>Heading</ToolbarButton>
                        <ToolbarButton>Bold</ToolbarButton>
                        <ToolbarButton>Italic</ToolbarButton>
                        <ToolbarButton>List</ToolbarButton>
                        <ToolbarButton>Link</ToolbarButton>
                        <ToolbarButton>Image</ToolbarButton>
                      </EditorToolbar>
                      <EditorContent>
                        <div 
                          style={{ 
                            whiteSpace: 'pre-wrap', 
                            fontFamily: 'monospace', 
                            fontSize: '14px',
                            lineHeight: 1.5
                          }}
                        >
                          {activePageContent}
                        </div>
                      </EditorContent>
                    </EditorContainer>
                    
                    <div style={{ marginTop: '20px' }}>
                      <FormGroup>
                        <FormLabel>SEO Title</FormLabel>
                        <FormInput defaultValue="Rules & Guidelines | Squid Game 2 Official Website" />
                      </FormGroup>
                      
                      <FormGroup>
                        <FormLabel>SEO Description</FormLabel>
                        <FormTextarea defaultValue="Learn the official rules and guidelines for Squid Game 2. Find information about eligibility, game structure, and prize distribution." />
                      </FormGroup>
                      
                      <FormGroup>
                        <FormLabel>Last Updated</FormLabel>
                        <div style={{ color: '#999', fontSize: '0.9rem' }}>
                          Last modified on July 28, 2023 by Admin
                        </div>
                      </FormGroup>
                    </div>
                  </>
                )}
                
                {activeContentSection === 'media' && (
                  <>
                    <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center', marginBottom: '20px' }}>
                      <FormGroup style={{ flex: 1, marginRight: '20px', marginBottom: 0 }}>
                        <SearchInput 
                          type="text" 
                          placeholder="Search media library..." 
                        />
                      </FormGroup>
                      <div>
                        <ActionButton>Upload New</ActionButton>
                        <ActionButton secondary style={{ marginLeft: '10px' }}>Filter</ActionButton>
                      </div>
                    </div>
                    
                    <MediaGrid>
                      {mockContent.media.map(item => (
                        <MediaItem key={item.id}>
                          <MediaImage src={item.url} />
                          <MediaActions className="media-actions">
                            <div style={{ fontSize: '0.9rem' }}>{item.name}</div>
                            <div>
                              <ActionButton style={{ padding: '3px 6px', fontSize: '0.8rem' }}>View</ActionButton>
                            </div>
                          </MediaActions>
                        </MediaItem>
                      ))}
                    </MediaGrid>
                    
                    <div style={{ marginTop: '20px', textAlign: 'center' }}>
                      <ActionButton secondary>Load More</ActionButton>
                    </div>
                  </>
                )}
                
                {activeContentSection === 'email' && (
                  <>
                    <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center', marginBottom: '20px' }}>
                      <FormGroup style={{ flex: 1, marginRight: '20px', marginBottom: 0 }}>
                        <FormLabel>Select Template</FormLabel>
                        <FormSelect defaultValue="1">
                          {mockContent.emailTemplates.map(template => (
                            <option key={template.id} value={template.id}>{template.name}</option>
                          ))}
                        </FormSelect>
                      </FormGroup>
                      <div>
                        <ActionButton>Save Template</ActionButton>
                        <ActionButton secondary style={{ marginLeft: '10px' }}>Send Test</ActionButton>
                      </div>
                    </div>
                    
                    <FormGroup>
                      <FormLabel>Email Subject</FormLabel>
                      <FormInput defaultValue="Welcome to Squid Game 2" />
                    </FormGroup>
                    
                    <EditorContainer>
                      <EditorToolbar>
                        <ToolbarButton>Heading</ToolbarButton>
                        <ToolbarButton>Bold</ToolbarButton>
                        <ToolbarButton>Italic</ToolbarButton>
                        <ToolbarButton>List</ToolbarButton>
                        <ToolbarButton>Link</ToolbarButton>
                        <ToolbarButton>Image</ToolbarButton>
                        <ToolbarButton>Personalize</ToolbarButton>
                      </EditorToolbar>
                      <EditorContent>
                        <div style={{ lineHeight: 1.5 }}>
                          <p>Dear [FIRST_NAME],</p>
                          <p>Thank you for your interest in Squid Game 2! We're excited to confirm that we've received your registration.</p>
                          <p>Your application is now being reviewed by our team. We'll notify you of your status within the next 2-3 weeks.</p>
                          <p>In the meantime, please make sure to:</p>
                          <ul>
                            <li>Complete any pending sections of your application</li>
                            <li>Verify your contact information is correct</li>
                            <li>Follow us on social media for updates</li>
                          </ul>
                          <p>If you have any questions, please don't hesitate to contact our support team.</p>
                          <p>Best regards,<br />The Squid Game Team</p>
                        </div>
                      </EditorContent>
                    </EditorContainer>
                    
                    <div style={{ marginTop: '20px' }}>
                      <FormGroup>
                        <FormLabel>Template Variables</FormLabel>
                        <div style={{ display: 'flex', flexWrap: 'wrap', gap: '10px' }}>
                          <ActionButton secondary style={{ fontSize: '0.9rem' }}>[FIRST_NAME]</ActionButton>
                          <ActionButton secondary style={{ fontSize: '0.9rem' }}>[LAST_NAME]</ActionButton>
                          <ActionButton secondary style={{ fontSize: '0.9rem' }}>[APPLICATION_ID]</ActionButton>
                          <ActionButton secondary style={{ fontSize: '0.9rem' }}>[STATUS]</ActionButton>
                          <ActionButton secondary style={{ fontSize: '0.9rem' }}>[DATE]</ActionButton>
                        </div>
                      </FormGroup>
                    </div>
                  </>
                )}
                
                {activeContentSection === 'legal' && (
                  <>
                    <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center', marginBottom: '20px' }}>
                      <h3 style={{ margin: 0 }}>Legal Documents</h3>
                      <div>
                        <ActionButton>Upload Document</ActionButton>
                        <ActionButton secondary style={{ marginLeft: '10px' }}>New Version</ActionButton>
                      </div>
                    </div>
                    
                    {mockContent.legalDocuments.map(doc => (
                      <DocumentItem key={doc.id}>
                        <DocumentInfo>
                          <DocumentIcon>{doc.type}</DocumentIcon>
                          <div>
                            <div style={{ fontWeight: 'bold' }}>{doc.name}</div>
                            <DocumentMeta>
                              Version {doc.version} • {doc.size} • Updated {doc.updated}
                            </DocumentMeta>
                          </div>
                        </DocumentInfo>
                        <div>
                          <ActionButton style={{ padding: '3px 8px', fontSize: '0.9rem', marginRight: '5px' }}>Download</ActionButton>
                          <ActionButton secondary style={{ padding: '3px 8px', fontSize: '0.9rem' }}>Edit</ActionButton>
                        </div>
                      </DocumentItem>
                    ))}
                    
                    <div style={{ marginTop: '20px' }}>
                      <FormGroup>
                        <FormLabel>Release Form Settings</FormLabel>
                        <div style={{ display: 'flex', gap: '20px' }}>
                          <div style={{ flex: 1 }}>
                            <CheckboxLabel>
                              <input type="checkbox" checked readOnly />
                              Require electronic signature
                            </CheckboxLabel>
                          </div>
                          <div style={{ flex: 1 }}>
                            <CheckboxLabel>
                              <input type="checkbox" checked readOnly />
                              Store consent logs
                            </CheckboxLabel>
                          </div>
                          <div style={{ flex: 1 }}>
                            <CheckboxLabel>
                              <input type="checkbox" checked readOnly />
                              Email copies to applicants
                            </CheckboxLabel>
                          </div>
                        </div>
                      </FormGroup>
                    </div>
                  </>
                )}
              </ContentArea>
            </ContentGrid>
          </>
        );
        
      default:
        return <div>Select a section from the sidebar</div>;
    }
  };
  
  // Helper function for ordinal suffixes
  const getOrdinalSuffix = (num) => {
    const j = num % 10;
    const k = num % 100;
    if (j === 1 && k !== 11) {
      return 'st';
    }
    if (j === 2 && k !== 12) {
      return 'nd';
    }
    if (j === 3 && k !== 13) {
      return 'rd';
    }
    return 'th';
  };

  const handleLogout = () => {
    if (onLogout) {
      onLogout();
    }
  };

  return (
    <AdminContainer>
      <AdminHeader>
        <AdminTitle>Squid Game 2 - Admin Dashboard</AdminTitle>
        <LogoutButton onClick={handleLogout}>Logout</LogoutButton>
      </AdminHeader>
      
      <DashboardGrid>
        <Sidebar>
          <SectionTitle style={{ fontSize: '1.2rem' }}>Dashboard</SectionTitle>
          <NavItem 
            active={activeSection === 'participants'} 
            onClick={() => setActiveSection('participants')}
          >
            Participant Management
          </NavItem>
          <NavItem 
            active={activeSection === 'videoReview'} 
            onClick={() => setActiveSection('videoReview')}
          >
            Video Review
          </NavItem>
          <NavItem 
            active={activeSection === 'backgroundCheck'} 
            onClick={() => setActiveSection('backgroundCheck')}
          >
            Background Checks
          </NavItem>
          <NavItem 
            active={activeSection === 'selection'} 
            onClick={() => setActiveSection('selection')}
          >
            Selection & Grouping
          </NavItem>
          <NavItem 
            active={activeSection === 'competition'} 
            onClick={() => setActiveSection('competition')}
          >
            Competition Management
          </NavItem>
          <NavItem 
            active={activeSection === 'analytics'} 
            onClick={() => setActiveSection('analytics')}
          >
            Analytics Dashboard
          </NavItem>
          <NavItem 
            active={activeSection === 'content'} 
            onClick={() => setActiveSection('content')}
          >
            Content Management
          </NavItem>
        </Sidebar>
        
        <MainContent>
          {renderContent()}
        </MainContent>
      </DashboardGrid>
    </AdminContainer>
  );
};

export default AdminDashboard; 