import React, { useState } from 'react';
import styled from 'styled-components';

const LoginContainer = styled.div`
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100vh;
  background-color: #111;
  background-image: radial-gradient(#222 1px, transparent 1px);
  background-size: 20px 20px;
`;

const LoginCard = styled.div`
  width: 100%;
  max-width: 400px;
  background-color: #222;
  border-radius: 10px;
  padding: 30px;
  box-shadow: 0 0 20px rgba(255, 0, 60, 0.3);
  border: 1px solid rgba(255, 0, 60, 0.4);
`;

const LoginTitle = styled.h1`
  font-size: 2rem;
  color: white;
  text-align: center;
  margin-bottom: 30px;
  text-shadow: 0 0 10px var(--neon-red);
`;

const LoginForm = styled.form`
  display: flex;
  flex-direction: column;
`;

const InputGroup = styled.div`
  margin-bottom: 20px;
`;

const InputLabel = styled.label`
  display: block;
  color: #ccc;
  margin-bottom: 8px;
  font-size: 0.9rem;
`;

const Input = styled.input`
  width: 100%;
  padding: 12px;
  background-color: #333;
  border: 1px solid ${props => props.error ? 'var(--neon-red)' : '#444'};
  border-radius: 4px;
  color: white;
  font-size: 1rem;
  
  &:focus {
    outline: none;
    border-color: var(--neon-red);
    box-shadow: 0 0 5px rgba(255, 0, 60, 0.5);
  }
`;

const ErrorMessage = styled.div`
  color: var(--neon-red);
  font-size: 0.8rem;
  margin-top: 5px;
`;

const LoginButton = styled.button`
  background-color: var(--neon-red);
  color: white;
  border: none;
  padding: 12px;
  border-radius: 4px;
  font-size: 1rem;
  font-weight: bold;
  cursor: pointer;
  margin-top: 10px;
  transition: all 0.2s ease;
  
  &:hover {
    background-color: rgba(255, 0, 60, 0.8);
    box-shadow: 0 0 10px var(--neon-red);
  }
  
  &:disabled {
    background-color: #444;
    cursor: not-allowed;
  }
`;

const Logo = styled.div`
  display: flex;
  justify-content: center;
  margin-bottom: 20px;
  
  img {
    height: 60px;
  }
`;

const BackToHome = styled.div`
  text-align: center;
  margin-top: 20px;
  
  a {
    color: #888;
    text-decoration: none;
    font-size: 0.9rem;
    
    &:hover {
      color: var(--neon-red);
      text-decoration: underline;
    }
  }
`;

const AdminLogin = ({ onLogin }) => {
  const [formData, setFormData] = useState({
    username: '',
    password: ''
  });
  
  const [errors, setErrors] = useState({});
  const [loginError, setLoginError] = useState('');
  
  // Hardcoded admin credentials
  const ADMIN_USERNAME = 'admin';
  const ADMIN_PASSWORD = 'squid123';
  
  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData({
      ...formData,
      [name]: value
    });
    
    // Clear errors when typing
    if (errors[name]) {
      setErrors({
        ...errors,
        [name]: ''
      });
    }
    
    // Clear login error when typing
    if (loginError) {
      setLoginError('');
    }
  };
  
  const validateForm = () => {
    const newErrors = {};
    
    if (!formData.username.trim()) {
      newErrors.username = 'Username is required';
    }
    
    if (!formData.password) {
      newErrors.password = 'Password is required';
    }
    
    setErrors(newErrors);
    return Object.keys(newErrors).length === 0;
  };
  
  const handleSubmit = (e) => {
    e.preventDefault();
    
    if (validateForm()) {
      // Check credentials
      if (formData.username === ADMIN_USERNAME && formData.password === ADMIN_PASSWORD) {
        // Login successful
        onLogin();
      } else {
        // Login failed
        setLoginError('Invalid username or password');
      }
    }
  };
  
  return (
    <LoginContainer>
      <LoginCard>
        <Logo>
          <div style={{ fontSize: '28px', color: 'var(--neon-red)', fontWeight: 'bold' }}>SQUID GAME</div>
        </Logo>
        <LoginTitle>Admin Login</LoginTitle>
        
        {loginError && <ErrorMessage style={{ textAlign: 'center', marginBottom: '15px' }}>{loginError}</ErrorMessage>}
        
        <LoginForm onSubmit={handleSubmit}>
          <InputGroup>
            <InputLabel htmlFor="username">Username</InputLabel>
            <Input 
              type="text" 
              id="username" 
              name="username" 
              value={formData.username}
              onChange={handleChange}
              error={!!errors.username}
            />
            {errors.username && <ErrorMessage>{errors.username}</ErrorMessage>}
          </InputGroup>
          
          <InputGroup>
            <InputLabel htmlFor="password">Password</InputLabel>
            <Input 
              type="password" 
              id="password" 
              name="password" 
              value={formData.password}
              onChange={handleChange}
              error={!!errors.password}
            />
            {errors.password && <ErrorMessage>{errors.password}</ErrorMessage>}
          </InputGroup>
          
          <LoginButton type="submit">
            Login
          </LoginButton>
        </LoginForm>
        
        <BackToHome>
          <a href="/">Back to Homepage</a>
        </BackToHome>
      </LoginCard>
    </LoginContainer>
  );
};

export default AdminLogin; 