import React from 'react';
import styled from 'styled-components';

const StyledAtlosButton = styled.button`
  background: linear-gradient(to right, #0066ff, #00ccff);
  color: white;
  font-weight: 700;
  font-size: 1.2rem;
  padding: 0.8rem 2rem;
  border: none;
  border-radius: 5px;
  cursor: pointer;
  transition: all 0.3s ease;
  margin-top: 1rem;
  
  &:hover {
    transform: scale(1.05);
    box-shadow: 0 0 15px #0066ff;
  }
`;

const AtlosPayButton = ({ amount, currency = 'USD', merchantId = 'DG19KH0XGZ', buttonText, onSuccess }) => {
  const handlePayment = () => {
    if (window.atlos) {
      window.atlos.Pay({
        merchantId: merchantId,
        orderId: `SG2-${Date.now()}`, 
        orderAmount: amount,
        orderCurrency: currency,
        onSuccess: () => {
          console.log('Payment successful');
          if (onSuccess && typeof onSuccess === 'function') {
            onSuccess();
          }
        }
      });
    } else {
      console.error('Atlos payment script not loaded');
    }
  };

  return (
    <StyledAtlosButton onClick={handlePayment}>
      {buttonText || `Pay $${parseFloat(amount).toFixed(2)} with Atlos`}
    </StyledAtlosButton>
  );
};

export default AtlosPayButton; 