import React, { useState, useEffect } from 'react';
import styled, { keyframes } from 'styled-components';

const fadeIn = keyframes`
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
`;

const rotate = keyframes`
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(360deg);
  }
`;

const bounce = keyframes`
  0%, 100% {
    transform: translateY(0);
  }
  50% {
    transform: translateY(-10px);
  }
`;

const pulse = keyframes`
  0% {
    opacity: 1;
  }
  50% {
    opacity: 0.5;
  }
  100% {
    opacity: 1;
  }
`;

const Container = styled.div`
  width: 100%;
  max-width: 1000px;
  margin: 0 auto 40px;
  padding: 30px;
  position: relative;
  z-index: 2;
  background: linear-gradient(to bottom, rgba(58, 43, 131, 0.7), rgba(42, 27, 99, 0.8));
  border-radius: 15px;
  box-shadow: 0 10px 30px rgba(153, 102, 255, 0.3);
`;

const SectionTitle = styled.h2`
  color: white;
  text-align: center;
  font-size: 2.5rem;
  margin-bottom: 30px;
  text-transform: uppercase;
  position: relative;
  text-shadow: 0 0 10px rgba(255, 51, 102, 0.6);
  
  &:after {
    content: '';
    position: absolute;
    bottom: -10px;
    left: 50%;
    transform: translateX(-50%);
    width: 100px;
    height: 3px;
    background: linear-gradient(to right, transparent, var(--neon-red), transparent);
  }
  
  @media (max-width: 768px) {
    font-size: 1.8rem;
  }
`;

const GridContainer = styled.div`
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 20px;
  
  @media (max-width: 768px) {
    grid-template-columns: 1fr;
  }
`;

const BtsCard = styled.div`
  background: linear-gradient(135deg, rgba(58, 43, 131, 0.7) 0%, rgba(42, 27, 99, 0.7) 100%);
  border-radius: 10px;
  overflow: hidden;
  box-shadow: 0 5px 15px rgba(58, 43, 131, 0.6);
  transition: transform 0.3s ease;
  animation: ${fadeIn} 0.5s ease-out;
  animation-delay: ${props => props.index * 0.2}s;
  animation-fill-mode: both;
  border: 1px solid rgba(255, 255, 255, 0.1);
  
  &:hover {
    transform: translateY(-5px);
    box-shadow: 0 10px 20px rgba(255, 51, 102, 0.4);
    border-color: rgba(255, 51, 102, 0.4);
  }
`;

const CardImage = styled.div`
  height: 180px;
  background-image: url(${props => props.image});
  background-size: cover;
  background-position: center;
  position: relative;
  
  &:before {
    content: '';
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background: linear-gradient(to bottom, rgba(58, 43, 131, 0.1), rgba(42, 27, 99, 0.6));
  }
`;

const PlayButton = styled.div`
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  width: 50px;
  height: 50px;
  background-color: rgba(255, 51, 102, 0.8);
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;
  opacity: 0;
  transition: opacity 0.3s ease, transform 0.3s ease;
  
  &:after {
    content: '';
    width: 0;
    height: 0;
    border-top: 10px solid transparent;
    border-bottom: 10px solid transparent;
    border-left: 15px solid white;
    margin-left: 3px;
  }
  
  ${BtsCard}:hover & {
    opacity: 1;
    animation: ${bounce} 1s infinite;
  }
`;

const CardContent = styled.div`
  padding: 15px;
`;

const CardTitle = styled.h3`
  color: white;
  margin: 0 0 10px 0;
  font-size: 1.2rem;
`;

const CardDescription = styled.p`
  color: #ffffff;
  margin: 0;
  font-size: 0.9rem;
  line-height: 1.4;
`;

const ViewMoreButton = styled.button`
  background: transparent;
  border: 2px solid var(--neon-red);
  color: white;
  padding: 10px 20px;
  font-size: 1rem;
  border-radius: 5px;
  margin: 30px auto 0;
  display: block;
  cursor: pointer;
  transition: all 0.3s ease;
  position: relative;
  overflow: hidden;
  
  &:before {
    content: '';
    position: absolute;
    top: 0;
    left: -100%;
    width: 100%;
    height: 100%;
    background: linear-gradient(
      90deg,
      transparent,
      rgba(255, 51, 102, 0.5),
      transparent
    );
    transition: 0.5s;
  }
  
  &:hover {
    background-color: rgba(255, 51, 102, 0.3);
    transform: scale(1.05);
    
    &:before {
      left: 100%;
    }
  }
`;

const LoadingSpinner = styled.div`
  width: 40px;
  height: 40px;
  border: 4px solid rgba(255, 255, 255, 0.1);
  border-left-color: var(--neon-red);
  border-radius: 50%;
  animation: ${rotate} 1s linear infinite;
  margin: 20px auto;
`;

const WatchNowText = styled.div`
  color: var(--neon-red);
  font-size: 0.9rem;
  font-weight: 700;
  margin-top: 10px;
  text-transform: uppercase;
  letter-spacing: 1px;
  animation: ${pulse} 2s infinite;
`;

const btsItems = [
  {
    id: 1,
    title: 'Setting Up The Games',
    description: 'Watch how we built the massive sets for Squid Game 2 challenges.',
    image: '/mrbp.png'
  },
  {
    id: 2,
    title: 'Contestant Selection',
    description: 'See how we selected from thousands of applicants for this season.',
    image: '/mrbp1.png'
  },
  {
    id: 3,
    title: 'Training The Staff',
    description: 'Behind the scenes with our game masters and staff preparation.',
    image: '/mrbp2.png'
  },
  {
    id: 4,
    title: 'Prize Money Reveal',
    description: 'The moment when contestants saw the prize money for the first time.',
    image: '/mrbp3.png'
  },
  {
    id: 5,
    title: 'Creating The Challenges',
    description: 'How we designed the games to be challenging yet fair for all players.',
    image: '/mrbp2.png'
  },
  {
    id: 6,
    title: 'Season 1 Highlights',
    description: 'The most intense and exciting moments from the first season.',
    image: '/mrq.jpg',
    videoUrl: 'https://www.youtube.com/watch?v=0e3GPea1Tyg&pp=ygUdbXIgYmVhc3Qgc3F1aWQgZ2FtZSAyIHRyYWlsZXLSBwkJjQkBhyohjO8%3D'
  }
];

const BehindTheScenes = () => {
  const [loading, setLoading] = useState(true);
  const [visibleItems, setVisibleItems] = useState([]);
  
  useEffect(() => {
    // Simulate loading
    const timer = setTimeout(() => {
      setLoading(false);
      setVisibleItems(btsItems.slice(0, 3));
    }, 1000);
    
    return () => clearTimeout(timer);
  }, []);
  
  const handleViewMore = () => {
    if (visibleItems.length === 3) {
      setVisibleItems(btsItems);
    } else {
      setVisibleItems(btsItems.slice(0, 3));
    }
  };
  
  return (
    <Container>
      <SectionTitle>Behind The Scenes</SectionTitle>
      
      {loading ? (
        <LoadingSpinner />
      ) : (
        <>
          <GridContainer>
            {visibleItems.map((item, index) => (
              <BtsCard key={item.id} index={index} as={item.videoUrl ? 'a' : 'div'} href={item.videoUrl} target="_blank" rel="noopener noreferrer">
                <CardImage image={item.image}>
                  <PlayButton />
                </CardImage>
                <CardContent>
                  <CardTitle>{item.title}</CardTitle>
                  <CardDescription>{item.description}</CardDescription>
                  {item.videoUrl && <WatchNowText>Click to watch now</WatchNowText>}
                </CardContent>
              </BtsCard>
            ))}
          </GridContainer>
          
          <ViewMoreButton onClick={handleViewMore}>
            {visibleItems.length === 3 ? 'View More' : 'Show Less'}
          </ViewMoreButton>
        </>
      )}
    </Container>
  );
};

export default BehindTheScenes; 