import React, { useState, useEffect } from 'react';
import styled from 'styled-components';

const TimerContainer = styled.div`
  margin-bottom: 3rem;
  position: relative;
  padding: 20px;
  
  &::before {
    content: '';
    position: absolute;
    top: -10px;
    left: -10px;
    right: -10px;
    bottom: -10px;
    border: 1px solid rgba(255, 0, 60, 0.3);
    border-radius: 10px;
    z-index: -1;
    pointer-events: none;
  }
`;

const TimerTitle = styled.h3`
  font-size: 1.5rem;
  margin-bottom: 1.5rem;
  color: white;
  text-shadow: 0 0 5px var(--neon-red), 0 0 10px var(--neon-red);
  letter-spacing: 2px;
`;

const TimerDisplay = styled.div`
  display: flex;
  gap: 1.5rem;
  justify-content: center;
`;

const TimeUnit = styled.div`
  display: flex;
  flex-direction: column;
  align-items: center;
  background-color: rgba(0, 0, 0, 0.5);
  padding: 10px 15px;
  border-radius: 8px;
  min-width: 100px;
  border: 1px solid rgba(255, 0, 60, 0.2);
  
  @media (max-width: 768px) {
    min-width: 70px;
    padding: 8px 10px;
  }
`;

const TimeValue = styled.div`
  font-size: 3.5rem;
  font-weight: 700;
  color: white;
  text-shadow: 0 0 5px rgba(255, 0, 60, 0.5);
  
  @media (max-width: 768px) {
    font-size: 2rem;
  }
`;

const TimeLabel = styled.div`
  font-size: 0.8rem;
  color: #aaa;
  text-transform: uppercase;
  margin-top: 5px;
`;

const Separator = styled.div`
  font-size: 3.5rem;
  font-weight: 700;
  color: var(--neon-red);
  align-self: center;
  
  @media (max-width: 768px) {
    font-size: 2rem;
  }
`;

const CountdownTimer = () => {
  // Set countdown to 30 days from current date
  const calculateTargetDate = () => {
    const now = new Date();
    const target = new Date();
    target.setDate(now.getDate() + 30);
    return target;
  };
  
  const [targetDate] = useState(calculateTargetDate());
  
  const [timeLeft, setTimeLeft] = useState({
    days: 30,
    hours: 0,
    minutes: 0,
    seconds: 0
  });
  
  useEffect(() => {
    // Calculate initial time difference immediately
    const calculateTimeDifference = () => {
      const now = new Date();
      const difference = targetDate - now;
      
      if (difference <= 0) {
        return { days: 0, hours: 0, minutes: 0, seconds: 0 };
      }
      
      const days = Math.floor(difference / (1000 * 60 * 60 * 24));
      const hours = Math.floor((difference / (1000 * 60 * 60)) % 24);
      const minutes = Math.floor((difference / (1000 * 60)) % 60);
      const seconds = Math.floor((difference / 1000) % 60);
      
      return { days, hours, minutes, seconds };
    };
    
    // Set initial time immediately
    setTimeLeft(calculateTimeDifference());
    
    // Update time every second
    const interval = setInterval(() => {
      setTimeLeft(calculateTimeDifference());
    }, 1000);
    
    return () => clearInterval(interval);
  }, [targetDate]);
  
  return (
    <TimerContainer>
      <TimerTitle>REGISTRATION CLOSES IN</TimerTitle>
      <TimerDisplay>
        <TimeUnit>
          <TimeValue>{timeLeft.days.toString().padStart(2, '0')}</TimeValue>
          <TimeLabel>Days</TimeLabel>
        </TimeUnit>
        <Separator>:</Separator>
        <TimeUnit>
          <TimeValue>{timeLeft.hours.toString().padStart(2, '0')}</TimeValue>
          <TimeLabel>Hours</TimeLabel>
        </TimeUnit>
        <Separator>:</Separator>
        <TimeUnit>
          <TimeValue>{timeLeft.minutes.toString().padStart(2, '0')}</TimeValue>
          <TimeLabel>Minutes</TimeLabel>
        </TimeUnit>
        <Separator>:</Separator>
        <TimeUnit>
          <TimeValue>{timeLeft.seconds.toString().padStart(2, '0')}</TimeValue>
          <TimeLabel>Seconds</TimeLabel>
        </TimeUnit>
      </TimerDisplay>
    </TimerContainer>
  );
};

export default CountdownTimer; 