import React, { useState } from 'react';
import styled from 'styled-components';
import AtlosPayButton from './AtlosPayButton';

const PaymentContainer = styled.div`
  margin-top: 2rem;
  width: 100%;
  position: relative;
  padding: 20px;
  
  &::before {
    content: '';
    position: absolute;
    top: -10px;
    left: -10px;
    right: -10px;
    bottom: -10px;
    border: 1px solid rgba(255, 0, 60, 0.3);
    border-radius: 10px;
    z-index: -1;
    pointer-events: none;
  }
`;

const PaymentTitle = styled.h3`
  font-size: 1.5rem;
  margin-bottom: 1.5rem;
  color: white;
  text-shadow: 0 0 5px var(--neon-red), 0 0 10px var(--neon-red);
  letter-spacing: 2px;
  text-transform: uppercase;
`;

const PaymentDescription = styled.p`
  font-size: 1.1rem;
  color: #ccc;
  margin-bottom: 2rem;
  text-align: center;
  max-width: 600px;
  margin-left: auto;
  margin-right: auto;
`;

const SuccessMessage = styled.div`
  background-color: rgba(0, 128, 0, 0.2);
  border: 1px solid rgba(0, 128, 0, 0.5);
  border-radius: 5px;
  padding: 1rem;
  margin-top: 1rem;
  color: #00ff00;
  text-align: center;
  animation: fadeIn 0.5s ease;
  
  @keyframes fadeIn {
    from { opacity: 0; }
    to { opacity: 1; }
  }
`;

const Disclaimer = styled.div`
  margin-top: 2rem;
  padding-top: 1rem;
  border-top: 1px solid rgba(255, 255, 255, 0.1);
  color: #888;
  font-size: 0.8rem;
  line-height: 1.4;
`;

const DisclaimerTitle = styled.div`
  font-weight: bold;
  margin-bottom: 0.5rem;
  color: #aaa;
`;

const PrivacyLinks = styled.div`
  margin-top: 0.5rem;
  display: flex;
  justify-content: center;
  gap: 1.5rem;
`;

const PrivacyLink = styled.a`
  color: #aaa;
  text-decoration: underline;
  
  &:hover {
    color: var(--neon-red);
  }
`;

const AtlosContainer = styled.div`
  text-align: center;
  background-color: rgba(0, 102, 255, 0.1);
  padding: 30px;
  border-radius: 10px;
  border: 1px solid rgba(0, 102, 255, 0.3);
  margin: 30px auto;
  max-width: 500px;
`;

const PaymentSection = ({ onComplete }) => {
  const [showSuccess, setShowSuccess] = useState(false);
  
  // Fixed payment amount of $50
  const registrationFee = 50.00;
  
  // Handle successful payment
  const handlePaymentSuccess = () => {
    setShowSuccess(true);
    
    // After 3 seconds, call the onComplete callback
    setTimeout(() => {
      if (onComplete) onComplete();
    }, 3000);
  };

  return (
    <PaymentContainer>
      <PaymentTitle>Final Step: Payment</PaymentTitle>
      <PaymentDescription>
        To complete your application for Squid Game 2, a registration fee of ${registrationFee.toFixed(2)} is required.
      </PaymentDescription>
      
      <AtlosContainer>
        <AtlosPayButton 
          amount={registrationFee} 
          buttonText={`Pay $${registrationFee.toFixed(2)} Now`}
          onSuccess={handlePaymentSuccess}
          BuyCrypto={true}
        />
      </AtlosContainer>
      
      {showSuccess && (
        <SuccessMessage>
          Payment successful! Your application is now complete.
        </SuccessMessage>
      )}
      
      <Disclaimer>
        <DisclaimerTitle>Important Information</DisclaimerTitle>
        <p>
          The registration fee covers processing of your application only. It does not guarantee selection 
          for participation in Squid Game 2. Selected participants will be notified via the contact information provided.
        </p>
        <PrivacyLinks>
          <PrivacyLink href="#">Terms & Conditions</PrivacyLink>
          <PrivacyLink href="#">Privacy Policy</PrivacyLink>
          <PrivacyLink href="#">Refund Policy</PrivacyLink>
        </PrivacyLinks>
      </Disclaimer>
    </PaymentContainer>
  );
};

export default PaymentSection; 