import React, { useState } from 'react';
import styled, { keyframes } from 'styled-components';
import { Link } from 'react-router-dom';

const pulse = keyframes`
  0% {
    box-shadow: 0 0 0 0 rgba(255, 0, 60, 0.7);
  }
  70% {
    box-shadow: 0 0 0 15px rgba(255, 0, 60, 0);
  }
  100% {
    box-shadow: 0 0 0 0 rgba(255, 0, 60, 0);
  }
`;

const scale = keyframes`
  0% {
    transform: scale(1);
  }
  50% {
    transform: scale(1.05);
  }
  100% {
    transform: scale(1);
  }
`;

const ButtonContainer = styled.div`
  margin-top: 2rem;
  position: relative;
  
  &::before, &::after {
    content: '';
    position: absolute;
    width: 40px;
    height: 2px;
    background-color: var(--neon-red);
    top: 50%;
    transform: translateY(-50%);
  }
  
  &::before {
    left: -60px;
  }
  
  &::after {
    right: -60px;
  }
  
  @media (max-width: 768px) {
    &::before, &::after {
      display: none;
    }
  }
`;

const StyledButton = styled(Link)`
  background-color: var(--neon-red);
  color: white;
  font-size: ${props => props.isHovered ? '2.3rem' : '2.1rem'};
  font-weight: 800;
  padding: 1.2rem 4rem;
  border: none;
  border-radius: 5px;
  text-transform: uppercase;
  letter-spacing: 3px;
  transition: all 0.3s ease;
  position: relative;
  overflow: hidden;
  cursor: pointer;
  animation: ${pulse} 2s infinite, ${scale} 2s infinite;
  text-shadow: 0 0 5px rgba(255, 255, 255, 0.7);
  z-index: 1;
  display: inline-block;
  text-decoration: none;
  
  &:before {
    content: '';
    position: absolute;
    top: 0;
    left: -100%;
    width: 100%;
    height: 100%;
    background: linear-gradient(
      90deg,
      transparent,
      rgba(255, 255, 255, 0.4),
      transparent
    );
    transition: 0.5s;
    z-index: -1;
  }
  
  &:hover:before {
    left: 100%;
  }
  
  @media (max-width: 768px) {
    font-size: ${props => props.isHovered ? '1.7rem' : '1.5rem'};
    padding: 1rem 2.5rem;
  }
`;

const ButtonText = styled.span`
  position: relative;
  z-index: 2;
`;

const Modal = styled.div`
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-color: rgba(0, 0, 0, 0.8);
  display: ${props => (props.show ? 'flex' : 'none')};
  justify-content: center;
  align-items: center;
  z-index: 1000;
  backdrop-filter: blur(5px);
`;

const ModalContent = styled.div`
  background: linear-gradient(135deg, var(--bright-bg), var(--light-bg));
  border-radius: 10px;
  padding: 30px;
  width: 90%;
  max-width: 600px;
  max-height: 90vh;
  overflow-y: auto;
  position: relative;
  border: 2px solid var(--turquoise);
  box-shadow: 0 0 30px rgba(0, 243, 255, 0.3);
`;

const CloseButton = styled.button`
  position: absolute;
  top: 15px;
  right: 15px;
  background: transparent;
  border: none;
  color: white;
  font-size: 1.5rem;
  cursor: pointer;
  z-index: 1;
  
  &:hover {
    color: var(--neon-red);
  }
`;

const FormTitle = styled.h2`
  color: white;
  font-size: 2rem;
  margin-bottom: 20px;
  text-align: center;
  text-shadow: 0 0 10px var(--neon-blue);
`;

const Form = styled.form`
  display: flex;
  flex-direction: column;
  gap: 15px;
`;

const FormGroup = styled.div`
  display: flex;
  flex-direction: column;
`;

const Label = styled.label`
  color: white;
  margin-bottom: 5px;
  font-weight: 600;
`;

const Input = styled.input`
  padding: 12px;
  border-radius: 5px;
  border: 1px solid var(--turquoise);
  background-color: rgba(255, 255, 255, 0.1);
  color: white;
  font-size: 1rem;
  
  &:focus {
    outline: none;
    border-color: var(--neon-blue);
    box-shadow: 0 0 8px var(--neon-blue);
  }
`;

const Select = styled.select`
  padding: 12px;
  border-radius: 5px;
  border: 1px solid var(--turquoise);
  background-color: rgba(255, 255, 255, 0.1);
  color: white;
  font-size: 1rem;
  
  &:focus {
    outline: none;
    border-color: var(--neon-blue);
    box-shadow: 0 0 8px var(--neon-blue);
  }
  
  option {
    background-color: var(--bright-bg);
    color: black;
  }
`;

// For better dropdown visibility
const CountrySelect = styled(Select)`
  height: auto;
  max-height: 44px;
  
  &::-webkit-scrollbar {
    width: 10px;
  }
  
  &::-webkit-scrollbar-track {
    background: var(--bright-bg);
  }
  
  &::-webkit-scrollbar-thumb {
    background-color: var(--turquoise);
    border-radius: 10px;
  }
`;

const SubmitButton = styled.button`
  background-color: var(--neon-blue);
  color: white;
  font-size: 1.2rem;
  font-weight: 700;
  padding: 12px;
  border: none;
  border-radius: 5px;
  margin-top: 15px;
  cursor: pointer;
  transition: all 0.3s ease;
  text-transform: uppercase;
  
  &:hover {
    background-color: var(--turquoise);
    transform: translateY(-3px);
    box-shadow: 0 5px 15px rgba(0, 243, 255, 0.4);
  }
`;

const countries = [
  "Afghanistan", "Albania", "Algeria", "Andorra", "Angola", "Antigua and Barbuda", "Argentina", "Armenia", "Australia", "Austria", "Azerbaijan",
  "Bahamas", "Bahrain", "Bangladesh", "Barbados", "Belarus", "Belgium", "Belize", "Benin", "Bhutan", "Bolivia", "Bosnia and Herzegovina", "Botswana", "Brazil", "Brunei", "Bulgaria", "Burkina Faso", "Burundi",
  "Cabo Verde", "Cambodia", "Cameroon", "Canada", "Central African Republic", "Chad", "Chile", "China", "Colombia", "Comoros", "Congo", "Costa Rica", "Croatia", "Cuba", "Cyprus", "Czech Republic",
  "Denmark", "Djibouti", "Dominica", "Dominican Republic",
  "Ecuador", "Egypt", "El Salvador", "Equatorial Guinea", "Eritrea", "Estonia", "Eswatini", "Ethiopia",
  "Fiji", "Finland", "France",
  "Gabon", "Gambia", "Georgia", "Germany", "Ghana", "Greece", "Grenada", "Guatemala", "Guinea", "Guinea-Bissau", "Guyana",
  "Haiti", "Honduras", "Hungary",
  "Iceland", "India", "Indonesia", "Iran", "Iraq", "Ireland", "Israel", "Italy", "Ivory Coast",
  "Jamaica", "Japan", "Jordan",
  "Kazakhstan", "Kenya", "Kiribati", "Kuwait", "Kyrgyzstan",
  "Laos", "Latvia", "Lebanon", "Lesotho", "Liberia", "Libya", "Liechtenstein", "Lithuania", "Luxembourg",
  "Madagascar", "Malawi", "Malaysia", "Maldives", "Mali", "Malta", "Marshall Islands", "Mauritania", "Mauritius", "Mexico", "Micronesia", "Moldova", "Monaco", "Mongolia", "Montenegro", "Morocco", "Mozambique", "Myanmar",
  "Namibia", "Nauru", "Nepal", "Netherlands", "New Zealand", "Nicaragua", "Niger", "Nigeria", "North Korea", "North Macedonia", "Norway",
  "Oman",
  "Pakistan", "Palau", "Palestine", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Philippines", "Poland", "Portugal",
  "Qatar",
  "Romania", "Russia", "Rwanda",
  "Saint Kitts and Nevis", "Saint Lucia", "Saint Vincent and the Grenadines", "Samoa", "San Marino", "Sao Tome and Principe", "Saudi Arabia", "Senegal", "Serbia", "Seychelles", "Sierra Leone", "Singapore", "Slovakia", "Slovenia", "Solomon Islands", "Somalia", "South Africa", "South Korea", "South Sudan", "Spain", "Sri Lanka", "Sudan", "Suriname", "Sweden", "Switzerland", "Syria",
  "Taiwan", "Tajikistan", "Tanzania", "Thailand", "Timor-Leste", "Togo", "Tonga", "Trinidad and Tobago", "Tunisia", "Turkey", "Turkmenistan", "Tuvalu",
  "Uganda", "Ukraine", "United Arab Emirates", "United Kingdom", "United States", "Uruguay", "Uzbekistan",
  "Vanuatu", "Vatican City", "Venezuela", "Vietnam",
  "Yemen",
  "Zambia", "Zimbabwe"
];

const RegisterButton = () => {
  const [isHovered, setIsHovered] = useState(false);
  
  return (
    <ButtonContainer>
      <StyledButton 
        to="/register"
        isHovered={isHovered}
        onMouseEnter={() => setIsHovered(true)}
        onMouseLeave={() => setIsHovered(false)}
      >
        <ButtonText>Register Now</ButtonText>
      </StyledButton>
    </ButtonContainer>
  );
};

export default RegisterButton;