import React, { useState } from 'react';
import styled from 'styled-components';
import PaymentSection from './PaymentSection';

const FormContainer = styled.div`
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.9);
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 100;
  overflow-y: auto;
  padding: 20px;
`;

const StandaloneFormContainer = styled.div`
  width: 100%;
  max-width: ${props => props.expanded ? '100%' : '800px'};
  margin: 0 auto;
`;

const FormContent = styled.div`
  background-color: #111;
  border: none;
  border-radius: 10px;
  padding: ${props => props.expanded ? '40px' : '30px'};
  width: 100%;
  max-width: ${props => props.expanded ? '100%' : '800px'};
  box-shadow: none;
  position: relative;
  max-height: ${props => props.expanded ? 'none' : '90vh'};
  overflow-y: auto;
  display: flex;
  
  @media (max-width: 768px) {
    flex-direction: column;
    max-width: ${props => props.expanded ? '100%' : '600px'};
  }
`;

const StepsContainer = styled.div`
  width: ${props => props.expanded ? '280px' : '220px'};
  padding-right: ${props => props.expanded ? '40px' : '20px'};
  border-right: 1px solid rgba(255, 255, 255, 0.1);
  
  @media (max-width: 768px) {
    width: 100%;
    padding-right: 0;
    padding-bottom: 20px;
    margin-bottom: 20px;
    border-right: none;
    border-bottom: 1px solid rgba(255, 255, 255, 0.1);
  }
`;

const FormContentArea = styled.div`
  flex: 1;
  padding-left: ${props => props.expanded ? '50px' : '30px'};
  
  @media (max-width: 768px) {
    padding-left: 0;
  }
`;

const CloseButton = styled.button`
  position: absolute;
  top: 15px;
  right: 15px;
  background: none;
  border: none;
  color: white;
  font-size: 1.5rem;
  cursor: pointer;
  
  &:hover {
    color: #999;
  }
`;

const FormTitle = styled.h2`
  font-size: 2rem;
  color: white;
  text-align: center;
  margin-bottom: 2rem;
  text-shadow: none;
`;

const StepItem = styled.div`
  margin-bottom: 25px;
  display: flex;
  flex-direction: column;
`;

const StepCircle = styled.div`
  width: 40px;
  height: 40px;
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: ${props => props.active ? '#333' : props.completed ? 'rgba(255, 255, 255, 0.3)' : 'rgba(255, 255, 255, 0.1)'};
  color: white;
  font-weight: bold;
  box-shadow: none;
  margin-right: 15px;
  
  ${props => props.completed && `
    &::before {
      content: '✓';
      font-size: 1.2rem;
    }
  `}
`;

const StepContent = styled.div`
  display: flex;
  align-items: center;
`;

const StepLabel = styled.div`
  font-size: 1rem;
  color: ${props => props.active ? 'white' : '#aaa'};
  font-weight: ${props => props.active ? 'bold' : 'normal'};
`;

const StepProgress = styled.div`
  width: 2px;
  height: 25px;
  background-color: ${props => props.completed ? 'rgba(255, 255, 255, 0.3)' : 'rgba(255, 255, 255, 0.1)'};
  margin-left: 19px;
  margin-top: 5px;
  box-shadow: none;
`;

const FormSection = styled.div`
  margin-bottom: 2rem;
`;

const SectionTitle = styled.h3`
  font-size: 1.2rem;
  color: white;
  margin-bottom: 1rem;
`;

const InputGroup = styled.div`
  margin-bottom: 1rem;
`;

const Label = styled.label`
  display: block;
  color: white;
  margin-bottom: 0.5rem;
`;

const Input = styled.input`
  width: 100%;
  padding: 10px;
  background-color: #222;
  border: 1px solid #444;
  border-radius: 5px;
  color: white;
  font-size: 1rem;
  
  &:focus {
    border-color: #666;
    outline: none;
    box-shadow: none;
  }
`;

const TextArea = styled.textarea`
  width: 100%;
  padding: 10px;
  background-color: #222;
  border: 1px solid #444;
  border-radius: 5px;
  color: white;
  font-size: 1rem;
  min-height: 100px;
  resize: vertical;
  
  &:focus {
    border-color: #666;
    outline: none;
    box-shadow: none;
  }
`;

const Select = styled.select`
  width: 100%;
  padding: 10px;
  background-color: #222;
  border: 1px solid #444;
  border-radius: 5px;
  color: white;
  font-size: 1rem;
  
  &:focus {
    border-color: #666;
    outline: none;
    box-shadow: none;
  }
  
  option {
    background-color: #222;
    color: white;
  }
`;

const VideoUploadContainer = styled.div`
  border: 2px dashed #444;
  border-radius: 5px;
  padding: 20px;
  text-align: center;
  margin-top: 10px;
  cursor: pointer;
  transition: all 0.3s ease;
  
  &:hover {
    border-color: #666;
  }
`;

const VideoPreview = styled.video`
  width: 100%;
  margin-top: 15px;
  border-radius: 5px;
`;

const ButtonContainer = styled.div`
  display: flex;
  justify-content: space-between;
  margin-top: 2rem;
`;

const ActionButton = styled.button`
  background: ${props => props.secondary ? 'transparent' : '#333'};
  color: white;
  font-weight: 700;
  font-size: 1.2rem;
  padding: 12px 30px;
  border: ${props => props.secondary ? '1px solid #444' : 'none'};
  border-radius: 5px;
  cursor: pointer;
  transition: all 0.3s ease;
  
  &:hover {
    transform: scale(1.02);
    background: ${props => props.secondary ? 'rgba(255, 255, 255, 0.05)' : '#444'};
    box-shadow: none;
  }
  
  &:disabled {
    background: #222;
    cursor: not-allowed;
    transform: none;
    box-shadow: none;
  }
`;

const ErrorMessage = styled.div`
  color: #ff6b6b;
  font-size: 0.9rem;
  margin-top: 5px;
`;

const TwoColumnInputGrid = styled.div`
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: 20px;
  
  @media (max-width: 768px) {
    grid-template-columns: 1fr;
    gap: 0;
  }
`;

const RegisterForm = ({ onClose, standalone = false, expanded = false }) => {
  const [currentStep, setCurrentStep] = useState(1);
  const [formData, setFormData] = useState({
    firstName: '',
    lastName: '',
    email: '',
    phone: '',
    age: '',
    gender: '',
    address: '',
    city: '',
    state: '',
    zipCode: '',
    country: '',
    nationality: '',
    emergencyContactName: '',
    emergencyContactPhone: '',
    emergencyContactRelation: '',
    reason: '',
    video: null
  });
  
  const [videoPreview, setVideoPreview] = useState(null);
  const [errors, setErrors] = useState({});
  
  const handleChange = (e) => {
    const { name, value, type, checked } = e.target;
    setFormData({
      ...formData,
      [name]: type === 'checkbox' ? checked : value
    });
  };
  
  const handleVideoChange = (e) => {
    const file = e.target.files[0];
    if (file) {
      setFormData({
        ...formData,
        video: file
      });
      
      // Create preview URL
      const previewUrl = URL.createObjectURL(file);
      setVideoPreview(previewUrl);
    }
  };
  
  const validateStep = (step) => {
    const newErrors = {};
    
    if (step === 1) {
      // Basic personal information
      if (!formData.firstName.trim()) newErrors.firstName = 'First name is required';
      if (!formData.lastName.trim()) newErrors.lastName = 'Last name is required';
      if (!formData.email.trim()) newErrors.email = 'Email is required';
      if (!/^\S+@\S+\.\S+$/.test(formData.email)) newErrors.email = 'Email is invalid';
      if (!formData.phone.trim()) newErrors.phone = 'Phone number is required';
      if (!formData.age.trim()) newErrors.age = 'Age is required';
      if (parseInt(formData.age) < 18) newErrors.age = 'You must be at least 18 years old';
      if (!formData.gender) newErrors.gender = 'Gender is required';
      
      // Address information
      if (!formData.address.trim()) newErrors.address = 'Address is required';
      if (!formData.city.trim()) newErrors.city = 'City is required';
      if (!formData.country) newErrors.country = 'Country is required';
      
      // Emergency contact (at least name and phone)
      if (!formData.emergencyContactName.trim()) newErrors.emergencyContactName = 'Emergency contact name is required';
      if (!formData.emergencyContactPhone.trim()) newErrors.emergencyContactPhone = 'Emergency contact phone is required';
    } else if (step === 2) {
      if (!formData.reason.trim()) newErrors.reason = 'Please tell us why you should be chosen';
      if (!formData.video) newErrors.video = 'Please upload a video';
    }
    
    setErrors(newErrors);
    return Object.keys(newErrors).length === 0;
  };
  
  const handleNextStep = () => {
    if (validateStep(currentStep)) {
      setCurrentStep(currentStep + 1);
    }
  };
  
  const handlePrevStep = () => {
    setCurrentStep(currentStep - 1);
  };
  
  const handlePaymentComplete = () => {
    // Handle successful payment
    // This function should be implemented to handle the completion of the payment process
  };
  
  const renderStep = () => {
    switch(currentStep) {
      case 1:
        return (
          <form>
            <FormSection>
              <SectionTitle>Personal Information</SectionTitle>
              
              {expanded ? (
                <>
                  <TwoColumnInputGrid>
                    <div>
              <InputGroup>
                        <Label htmlFor="firstName">First Name *</Label>
                <Input 
                  type="text" 
                  id="firstName" 
                  name="firstName" 
                  value={formData.firstName} 
                  onChange={handleChange}
                />
                {errors.firstName && <ErrorMessage>{errors.firstName}</ErrorMessage>}
              </InputGroup>
              
              <InputGroup>
                        <Label htmlFor="email">Email *</Label>
                        <Input 
                          type="email" 
                          id="email" 
                          name="email" 
                          value={formData.email} 
                          onChange={handleChange}
                        />
                        {errors.email && <ErrorMessage>{errors.email}</ErrorMessage>}
                      </InputGroup>
                      
                      <InputGroup>
                        <Label htmlFor="age">Age *</Label>
                        <Input 
                          type="number" 
                          id="age" 
                          name="age" 
                          min="18" 
                          max="99" 
                          value={formData.age} 
                          onChange={handleChange}
                        />
                        {errors.age && <ErrorMessage>{errors.age}</ErrorMessage>}
                      </InputGroup>
                      
                      <InputGroup>
                        <Label htmlFor="gender">Gender *</Label>
                        <Select
                          id="gender"
                          name="gender"
                          value={formData.gender}
                          onChange={handleChange}
                        >
                          <option value="">Select gender</option>
                          <option value="male">Male</option>
                          <option value="female">Female</option>
                          <option value="non-binary">Non-binary</option>
                          <option value="prefer-not-to-say">Prefer not to say</option>
                        </Select>
                        {errors.gender && <ErrorMessage>{errors.gender}</ErrorMessage>}
                      </InputGroup>
                    </div>
                    
                    <div>
                      <InputGroup>
                        <Label htmlFor="lastName">Last Name *</Label>
                <Input 
                  type="text" 
                  id="lastName" 
                  name="lastName" 
                  value={formData.lastName} 
                  onChange={handleChange}
                />
                {errors.lastName && <ErrorMessage>{errors.lastName}</ErrorMessage>}
              </InputGroup>
              
              <InputGroup>
                        <Label htmlFor="phone">Phone Number *</Label>
                        <Input 
                          type="tel" 
                          id="phone" 
                          name="phone" 
                          value={formData.phone} 
                          onChange={handleChange}
                        />
                        {errors.phone && <ErrorMessage>{errors.phone}</ErrorMessage>}
                      </InputGroup>
                      
                      <InputGroup>
                        <Label htmlFor="nationality">Nationality</Label>
                        <Select
                          id="nationality"
                          name="nationality"
                          value={formData.nationality}
                          onChange={handleChange}
                        >
                          <option value="">Select nationality</option>
                          <option value="US">American</option>
                          <option value="UK">British</option>
                          <option value="CA">Canadian</option>
                          <option value="AU">Australian</option>
                          <option value="FR">French</option>
                          <option value="DE">German</option>
                          <option value="JP">Japanese</option>
                          <option value="KR">Korean</option>
                          <option value="CN">Chinese</option>
                          <option value="BR">Brazilian</option>
                          <option value="OTHER">Other</option>
                        </Select>
                      </InputGroup>
                    </div>
                  </TwoColumnInputGrid>
                  
                  <FormSection>
                    <SectionTitle>Address Information</SectionTitle>
                    <InputGroup>
                      <Label htmlFor="address">Street Address *</Label>
                      <TextArea 
                        id="address" 
                        name="address" 
                        value={formData.address} 
                        onChange={handleChange}
                      />
                      {errors.address && <ErrorMessage>{errors.address}</ErrorMessage>}
                    </InputGroup>
                    
                    <TwoColumnInputGrid>
                      <div>
                        <InputGroup>
                          <Label htmlFor="city">City *</Label>
                          <Input 
                            type="text" 
                            id="city" 
                            name="city" 
                            value={formData.city} 
                            onChange={handleChange}
                          />
                          {errors.city && <ErrorMessage>{errors.city}</ErrorMessage>}
                        </InputGroup>
                        
                        <InputGroup>
                          <Label htmlFor="zipCode">ZIP/Postal Code</Label>
                          <Input 
                            type="text" 
                            id="zipCode" 
                            name="zipCode" 
                            value={formData.zipCode} 
                            onChange={handleChange}
                          />
                        </InputGroup>
                      </div>
                      
                      <div>
                        <InputGroup>
                          <Label htmlFor="state">State/Province</Label>
                          <Input 
                            type="text" 
                            id="state" 
                            name="state" 
                            value={formData.state} 
                            onChange={handleChange}
                          />
                        </InputGroup>
                        
                        <InputGroup>
                          <Label htmlFor="country">Country of Residence *</Label>
                          <Select
                            id="country"
                            name="country"
                            value={formData.country}
                            onChange={handleChange}
                          >
                            <option value="">Select country</option>
                            <option value="US">United States</option>
                            <option value="UK">United Kingdom</option>
                            <option value="CA">Canada</option>
                            <option value="AU">Australia</option>
                            <option value="FR">France</option>
                            <option value="DE">Germany</option>
                            <option value="JP">Japan</option>
                            <option value="KR">South Korea</option>
                            <option value="CN">China</option>
                            <option value="BR">Brazil</option>
                            <option value="OTHER">Other</option>
                          </Select>
                          {errors.country && <ErrorMessage>{errors.country}</ErrorMessage>}
                        </InputGroup>
                      </div>
                    </TwoColumnInputGrid>
                  </FormSection>
                  
                  <FormSection>
                    <SectionTitle>Emergency Contact</SectionTitle>
                    <TwoColumnInputGrid>
                      <div>
                        <InputGroup>
                          <Label htmlFor="emergencyContactName">Emergency Contact Name *</Label>
                          <Input 
                            type="text" 
                            id="emergencyContactName" 
                            name="emergencyContactName" 
                            value={formData.emergencyContactName} 
                            onChange={handleChange}
                          />
                          {errors.emergencyContactName && <ErrorMessage>{errors.emergencyContactName}</ErrorMessage>}
                        </InputGroup>
                        
                        <InputGroup>
                          <Label htmlFor="emergencyContactRelation">Relationship</Label>
                          <Input 
                            type="text" 
                            id="emergencyContactRelation" 
                            name="emergencyContactRelation" 
                            value={formData.emergencyContactRelation} 
                            onChange={handleChange}
                          />
                        </InputGroup>
                      </div>
                      
                      <div>
                        <InputGroup>
                          <Label htmlFor="emergencyContactPhone">Emergency Contact Phone *</Label>
                          <Input 
                            type="tel" 
                            id="emergencyContactPhone" 
                            name="emergencyContactPhone" 
                            value={formData.emergencyContactPhone} 
                            onChange={handleChange}
                          />
                          {errors.emergencyContactPhone && <ErrorMessage>{errors.emergencyContactPhone}</ErrorMessage>}
                        </InputGroup>
                      </div>
                    </TwoColumnInputGrid>
                  </FormSection>
                </>
              ) : (
                <>
                  <TwoColumnInputGrid>
                    <div>
                      <InputGroup>
                        <Label htmlFor="firstName">First Name *</Label>
                        <Input 
                          type="text" 
                          id="firstName" 
                          name="firstName" 
                          value={formData.firstName} 
                          onChange={handleChange}
                        />
                        {errors.firstName && <ErrorMessage>{errors.firstName}</ErrorMessage>}
                      </InputGroup>
                      
                      <InputGroup>
                        <Label htmlFor="email">Email *</Label>
                <Input 
                  type="email" 
                  id="email" 
                  name="email" 
                  value={formData.email} 
                  onChange={handleChange}
                />
                {errors.email && <ErrorMessage>{errors.email}</ErrorMessage>}
              </InputGroup>
              
              <InputGroup>
                        <Label htmlFor="age">Age *</Label>
                <Input 
                  type="number" 
                  id="age" 
                  name="age" 
                  min="18" 
                  max="99" 
                  value={formData.age} 
                  onChange={handleChange}
                />
                {errors.age && <ErrorMessage>{errors.age}</ErrorMessage>}
              </InputGroup>
              
              <InputGroup>
                        <Label htmlFor="gender">Gender *</Label>
                        <Select
                          id="gender"
                          name="gender"
                          value={formData.gender}
                          onChange={handleChange}
                        >
                          <option value="">Select gender</option>
                          <option value="male">Male</option>
                          <option value="female">Female</option>
                          <option value="non-binary">Non-binary</option>
                          <option value="prefer-not-to-say">Prefer not to say</option>
                        </Select>
                        {errors.gender && <ErrorMessage>{errors.gender}</ErrorMessage>}
                      </InputGroup>
                    </div>
                    
                    <div>
                      <InputGroup>
                        <Label htmlFor="lastName">Last Name *</Label>
                        <Input 
                          type="text" 
                          id="lastName" 
                          name="lastName" 
                          value={formData.lastName} 
                          onChange={handleChange}
                        />
                        {errors.lastName && <ErrorMessage>{errors.lastName}</ErrorMessage>}
                      </InputGroup>
                      
                      <InputGroup>
                        <Label htmlFor="phone">Phone Number *</Label>
                        <Input 
                          type="tel" 
                          id="phone" 
                          name="phone" 
                          value={formData.phone} 
                          onChange={handleChange}
                        />
                        {errors.phone && <ErrorMessage>{errors.phone}</ErrorMessage>}
                      </InputGroup>
                      
                      <InputGroup>
                        <Label htmlFor="country">Country *</Label>
                        <Select
                          id="country"
                          name="country"
                          value={formData.country}
                          onChange={handleChange}
                        >
                          <option value="">Select country</option>
                          <option value="US">United States</option>
                          <option value="UK">United Kingdom</option>
                          <option value="CA">Canada</option>
                          <option value="AU">Australia</option>
                          <option value="FR">France</option>
                          <option value="DE">Germany</option>
                          <option value="JP">Japan</option>
                          <option value="KR">South Korea</option>
                          <option value="CN">China</option>
                          <option value="BR">Brazil</option>
                          <option value="OTHER">Other</option>
                        </Select>
                        {errors.country && <ErrorMessage>{errors.country}</ErrorMessage>}
                      </InputGroup>
                      
                      <InputGroup>
                        <Label htmlFor="city">City *</Label>
                        <Input 
                          type="text" 
                          id="city" 
                          name="city" 
                          value={formData.city} 
                          onChange={handleChange}
                        />
                        {errors.city && <ErrorMessage>{errors.city}</ErrorMessage>}
                      </InputGroup>
                    </div>
                  </TwoColumnInputGrid>
                  
                  <InputGroup>
                    <Label htmlFor="address">Address *</Label>
                <TextArea 
                  id="address" 
                  name="address" 
                  value={formData.address} 
                  onChange={handleChange}
                />
                    {errors.address && <ErrorMessage>{errors.address}</ErrorMessage>}
                  </InputGroup>
                  
                  <FormSection>
                    <SectionTitle>Emergency Contact</SectionTitle>
                    <TwoColumnInputGrid>
                      <div>
                        <InputGroup>
                          <Label htmlFor="emergencyContactName">Contact Name *</Label>
                          <Input 
                            type="text" 
                            id="emergencyContactName" 
                            name="emergencyContactName" 
                            value={formData.emergencyContactName} 
                            onChange={handleChange}
                          />
                          {errors.emergencyContactName && <ErrorMessage>{errors.emergencyContactName}</ErrorMessage>}
                        </InputGroup>
                      </div>
                      <div>
                        <InputGroup>
                          <Label htmlFor="emergencyContactPhone">Contact Phone *</Label>
                          <Input 
                            type="tel" 
                            id="emergencyContactPhone" 
                            name="emergencyContactPhone" 
                            value={formData.emergencyContactPhone} 
                            onChange={handleChange}
                          />
                          {errors.emergencyContactPhone && <ErrorMessage>{errors.emergencyContactPhone}</ErrorMessage>}
              </InputGroup>
                      </div>
                    </TwoColumnInputGrid>
                  </FormSection>
                </>
              )}
            </FormSection>
            
            <ButtonContainer>
              {!standalone ? (
              <ActionButton type="button" onClick={onClose} secondary>
                Cancel
              </ActionButton>
              ) : (
                <ActionButton type="button" onClick={() => window.location.href = '/'} secondary>
                  Back to Home
                </ActionButton>
              )}
              <ActionButton type="button" onClick={handleNextStep}>
                Next Step
              </ActionButton>
            </ButtonContainer>
          </form>
        );
      
      case 2:
        return (
          <form>
            <FormSection>
              <SectionTitle>Why Should We Choose You?</SectionTitle>
              
              {expanded ? (
                <TwoColumnInputGrid>
                  <div>
                    <InputGroup>
                      <Label htmlFor="reason">Tell us why you should be selected (max 500 characters)</Label>
                      <TextArea 
                        id="reason" 
                        name="reason" 
                        maxLength="500" 
                        value={formData.reason} 
                        onChange={handleChange}
                        style={{ height: videoPreview ? '150px' : '250px' }}
                      />
                      {errors.reason && <ErrorMessage>{errors.reason}</ErrorMessage>}
                    </InputGroup>
                  </div>
                  
                  <div>
                    <Label htmlFor="videoUpload">Upload a 30-second video explaining why you should be chosen</Label>
                    <VideoUploadContainer 
                      onClick={() => document.getElementById('videoUpload').click()}
                      style={{ height: videoPreview ? 'auto' : '80px', marginBottom: '15px' }}
                    >
                      <p>Click to upload video (max 50MB)</p>
                      <input 
                        type="file" 
                        id="videoUpload" 
                        accept="video/*" 
                        onChange={handleVideoChange} 
                        style={{ display: 'none' }}
                      />
                    </VideoUploadContainer>
                    {errors.video && !videoPreview && <ErrorMessage>{errors.video}</ErrorMessage>}
                    
                    {videoPreview && (
                      <VideoPreview controls src={videoPreview} />
                    )}
                  </div>
                </TwoColumnInputGrid>
              ) : (
                <>
              <InputGroup>
                    <Label htmlFor="reason">Tell us why you should be selected (max 500 characters)</Label>
                <TextArea 
                      id="reason" 
                      name="reason" 
                  maxLength="500" 
                      value={formData.reason} 
                  onChange={handleChange}
                />
                    {errors.reason && <ErrorMessage>{errors.reason}</ErrorMessage>}
              </InputGroup>
              
              <Label htmlFor="videoUpload">Upload a 30-second video explaining why you should be chosen</Label>
              <VideoUploadContainer onClick={() => document.getElementById('videoUpload').click()}>
                <p>Click to upload video (max 50MB)</p>
                <input 
                  type="file" 
                  id="videoUpload" 
                  accept="video/*" 
                  onChange={handleVideoChange} 
                  style={{ display: 'none' }}
                />
              </VideoUploadContainer>
                  {errors.video && !videoPreview && <ErrorMessage>{errors.video}</ErrorMessage>}
              
              {videoPreview && (
                <VideoPreview controls src={videoPreview} />
              )}
                </>
              )}
            </FormSection>
            
            <ButtonContainer>
              <ActionButton type="button" onClick={handlePrevStep} secondary>
                Previous
              </ActionButton>
              <ActionButton type="button" onClick={handleNextStep}>
                Next Step
              </ActionButton>
            </ButtonContainer>
          </form>
        );
      
      case 3:
        return (
          <PaymentSection onComplete={handlePaymentComplete} />
        );
      
      default:
        return null;
    }
  };
  
  const renderSteps = () => {
    const steps = [
      { id: 1, label: "Registration Details" },
      { id: 2, label: "Application Video" },
      { id: 3, label: "Payment & Confirmation" }
    ];
    
    return (
      <div>
        {steps.map((step, index) => (
          <div key={step.id}>
            <StepItem>
              <StepContent>
                <StepCircle
                  active={currentStep === step.id}
                  completed={currentStep > step.id}
                >
                  {currentStep <= step.id && step.id}
                </StepCircle>
                <StepLabel active={currentStep === step.id}>{step.label}</StepLabel>
              </StepContent>
              {index < steps.length - 1 && (
                <StepProgress completed={currentStep > step.id} />
              )}
            </StepItem>
          </div>
        ))}
      </div>
    );
  };
  
  const formContent = (
    <FormContent expanded={expanded}>
      {!standalone && <CloseButton onClick={onClose}>&times;</CloseButton>}
      
      <StepsContainer expanded={expanded}>
              {renderSteps()}
            </StepsContainer>
            
      <FormContentArea expanded={expanded}>
        {standalone ? null : <FormTitle>Register for Squid Game 2</FormTitle>}
              {renderStep()}
            </FormContentArea>
      </FormContent>
  );

  if (standalone) {
    return <StandaloneFormContainer expanded={expanded}>{formContent}</StandaloneFormContainer>;
  }

  return (
    <FormContainer>
      {formContent}
    </FormContainer>
  );
};

export default RegisterForm; 