import React from 'react';
import styled from 'styled-components';

const StatsContainer = styled.div`
  display: flex;
  justify-content: center;
  gap: 4rem;
  margin-bottom: 3rem;
  position: relative;
  padding: 20px 10px;
  
  &::before {
    content: '';
    position: absolute;
    top: -10px;
    left: -10px;
    right: -10px;
    bottom: -10px;
    border: 1px solid rgba(255, 0, 60, 0.3);
    border-radius: 10px;
    z-index: -1;
    pointer-events: none;
  }
  
  @media (max-width: 768px) {
    flex-direction: column;
    gap: 1.5rem;
  }
`;

const StatItem = styled.div`
  display: flex;
  flex-direction: column;
  align-items: center;
  background-color: rgba(0, 0, 0, 0.5);
  padding: 15px 20px;
  border-radius: 8px;
  min-width: 180px;
  border: 1px solid rgba(255, 0, 60, 0.2);
  transition: transform 0.3s ease, box-shadow 0.3s ease;
  
  &:hover {
    transform: translateY(-5px);
    box-shadow: 0 5px 15px rgba(255, 0, 60, 0.3);
  }
  
  @media (max-width: 768px) {
    min-width: 100%;
  }
`;

const StatValue = styled.div`
  font-size: 3rem;
  font-weight: 800;
  color: white;
  text-shadow: 0 0 10px var(--neon-red), 0 0 20px var(--neon-red);
  
  @media (max-width: 768px) {
    font-size: 2.5rem;
  }
`;

const StatLabel = styled.div`
  font-size: 1rem;
  font-weight: 600;
  color: #aaa;
  text-transform: uppercase;
  margin-top: 10px;
  letter-spacing: 1px;
  
  @media (max-width: 768px) {
    font-size: 0.9rem;
  }
`;

const Statistics = () => {
  return (
    <StatsContainer>
      <StatItem>
        <StatValue>600</StatValue>
        <StatLabel>Players</StatLabel>
      </StatItem>
      <StatItem>
        <StatValue>$6,000,000</StatValue>
        <StatLabel>Prize Pool</StatLabel>
      </StatItem>
      <StatItem>
        <StatValue>6</StatValue>
        <StatLabel>Games</StatLabel>
      </StatItem>
    </StatsContainer>
  );
};

export default Statistics; 