import React, { useState } from 'react';
import styled from 'styled-components';

const BackgroundContainer = styled.div`
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  overflow: hidden;
  z-index: -1;
`;

const VideoElement = styled.video`
  width: 100%;
  height: 100%;
  object-fit: cover;
  position: absolute;
  top: 0;
  left: 0;
  filter: brightness(85%) contrast(130%) saturate(160%);
  display: ${props => props.show ? 'block' : 'none'};
`;

const FallbackImage = styled.div`
  width: 100%;
  height: 100%;
  background-image: url(${props => props.image});
  background-size: cover;
  background-position: center center;
  position: absolute;
  top: 0;
  left: 0;
  filter: brightness(85%) contrast(130%) saturate(160%);
  display: ${props => props.show ? 'block' : 'none'};
`;

const TextOverlay = styled.div`
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  text-align: center;
  color: white;
  z-index: 3;
  width: 80%;
  max-width: 800px;
  display: ${props => props.show ? 'block' : 'none'};
`;

const ChallengeTitle = styled.h1`
  font-size: 5rem;
  text-transform: uppercase;
  font-weight: 800;
  margin-bottom: 1rem;
  text-shadow: 0 0 30px rgba(0, 0, 0, 0.8), 0 0 20px rgba(0, 0, 0, 0.9);
  
  @media (max-width: 768px) {
    font-size: 3rem;
  }
`;

const ChallengeDescription = styled.p`
  font-size: 2rem;
  text-shadow: 0 0 20px rgba(0, 0, 0, 0.8), 0 0 10px rgba(0, 0, 0, 0.9);
  margin-bottom: 2rem;
  
  @media (max-width: 768px) {
    font-size: 1.5rem;
  }
`;

const Overlay = styled.div`
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background: linear-gradient(
    135deg,
    rgba(13, 78, 109, 0.5) 0%,
    rgba(0, 226, 199, 0.4) 100%
  );
  z-index: 2;
`;

const VideoBackground = () => {
  const [videoFailed, setVideoFailed] = useState(false);
  const [videoLoaded, setVideoLoaded] = useState(false);
  const [useExtremeChallenge] = useState(true);

  // Primary video source - colorful players in a game
  const primaryVideo = "https://assets.mixkit.co/videos/preview/mixkit-people-in-a-colorful-game-4196-large.mp4";
  
  // Backup video source - dark corridor with red light
  const backupVideo = "https://assets.mixkit.co/videos/preview/mixkit-walking-down-a-corridor-with-red-lighting-42692-large.mp4";

  // Extreme Challenges image
  const extremeChallengesImage = "/mrbp.png";

  const handleVideoError = () => {
    setVideoFailed(true);
  };

  const handleVideoLoaded = () => {
    setVideoLoaded(true);
  };

  return (
    <BackgroundContainer>
      <FallbackImage 
        image={useExtremeChallenge ? extremeChallengesImage : 'https://images.unsplash.com/photo-1635126300353-f9ec9b5e9b39?q=80&w=2070&auto=format&fit=crop'}
        show={useExtremeChallenge || videoFailed || !videoLoaded} 
      />
      <VideoElement 
        autoPlay 
        loop 
        muted 
        playsInline
        onError={handleVideoError}
        onLoadedData={handleVideoLoaded}
        show={!useExtremeChallenge && !videoFailed && videoLoaded}
      >
        <source src={primaryVideo} type="video/mp4" />
        <source src={backupVideo} type="video/mp4" />
        Your browser does not support the video tag.
      </VideoElement>
      <Overlay />
      <TextOverlay show={useExtremeChallenge}>
        <ChallengeTitle>Extreme Challenges</ChallengeTitle>
        <ChallengeDescription>Join MrBeast for mind-blowing challenges with incredible prizes!</ChallengeDescription>
      </TextOverlay>
    </BackgroundContainer>
  );
};

export default VideoBackground; 